# frozen_string_literal: true

module ApplicationCable
  class Channel < ActionCable::Channel::Base
    class << self
      def prefix
        :"#{channel_name}:subscriber"
      end

      def subscribers
        User.where(id: subscriber_ids)
      end

      def subscriber_ids
        subscriber_keys.map { |key| key.sub("#{prefix}:", '') }
      end

      def subscriber_keys
        Redis.current.keys("#{prefix}:*")
      end

      def add(user_id)
        Redis.current.expire("#{prefix}:#{user_id}", 12.hours)
        value = Redis.current.incr("#{prefix}:#{user_id}")
        value
      end

      def delete(user_id)
        value = Redis.current.decr("#{prefix}:#{user_id}")
        Redis.current.del("#{prefix}:#{user_id}") if value <= 0
        value
      end

      def any_subscriber?
        subscriber_keys.any?
      end
    end
  end
end
