# frozen_string_literal: true

module ApplicationCable
  class Connection < ActionCable::Connection::Base
    include JWTSessions::RailsAuthorization

    identified_by :current_user

    def connect
      self.current_user = find_verified_user
    end

    def disconnect; end

    def find_verified_user
      token = request_cookies[JWTSessions.cookie_by(:access)]
      if JWTSessions::Session.new.session_exists?(token, :access)
        payload = JWTSessions::Token.decode!(token).first
        User.registered.find(payload['user_id'])
      else
        reject_unauthorized_connection
      end
    rescue ActiveRecord::RecordNotFound, JWTSessions::Errors::Unauthorized
      reject_unauthorized_connection
    end

    def current_project_type
      current_user = find_verified_user
      @current_project_type ||= begin
        (current_user.superadmin? ? request_cookies[:project_type] : current_user.project_type).presence
      end || current_user.project_type
    end
  end
end
