# frozen_string_literal: true

# Take a signed permanent reference for a blob and turn it into an expiring service URL for download.
# Note: These URLs are publicly accessible. If you need to enforce access protection beyond the
# security-through-obscurity factor of the signed blob references, you'll need to implement your own
# authenticated redirection controller.
#
# Patching the default rails controller to allow frontend to use fetch without facing CORS issues
# when being redirected to s3 without header Origin being set
module ActiveStorage
  class BlobsController < ActiveStorage::BaseController
    include ActiveStorage::SetBlob

    def show
      expires_in ActiveStorage.service_urls_expire_in
      render json: { url: @blob.service_url(disposition: params[:disposition]) }
    end
  end
end
