# frozen_string_literal: true

module Api
  module Admin
    class ChecklistsController < BaseController
      before_action :set_checklist, only: %i[show update destroy]

      def index
        authorize :checklist, :index?
        @checklists = ChecklistSearcher.call(params, current_user, current_project_type)
        @pagy = Pagy.new_from_searchkick(@checklists)
      end

      def show
        authorize @checklist
      end

      def create
        authorize :checklist, :create?

        result = Checklists::Create.call(checklist_params, current_user)

        if result.success?
          @checklist = result.value!
          render :show, status: :created
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def update
        authorize @checklist

        result = Checklists::Update.call(@checklist, checklist_params, current_user)

        if result.success?
          render :show
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def destroy
        authorize @checklist

        if @checklist.destroy
          head :no_content
        else
          render json: { code: 422, errors: @checklist.errors.full_messages }, status: :unprocessable_entity
        end
      end

      private

      def set_checklist
        @checklist = Checklist.find(params[:id])
      end

      def checklist_params
        params.permit(:name, :project_type, :raw_data)
      end
    end
  end
end
