# frozen_string_literal: true

module Api
  module Admin
    class CodebooksController < BaseController # rubocop:disable Metrics/ClassLength
      # TODO: extract requiring admin or superadmin permissions into some kind of AdminController
      # to get rid of this pointless boilerplate 'authorize' shit code

      # TODO: do we really need 10 non-DRY-at-all methods?
      # get /codebooks/:key
      # Codebook.for(params[:key])
      # authorize :codebook, params[:key].to_sym
      # pretend we're a model lol

      def administrative_districts
        authorize :codebook, (__method__.to_s + '?').to_sym

        data = AdministrativeDistrict.includes(:districts)
                                     .as_json(only: %i[id name], include: { districts: { only: %i[id name] } })

        render json: data
      end

      def curators
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = User.curator.not_archived.order(:last_name, :first_name, :middle_name).where(project_type: current_project_type)

        render partial: 'codebook', locals: { items: items, method_for_name: :short_full_name }
      end

      def territories
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Territory.all

        render partial: 'codebook', locals: { items: items }
      end

      def project_types
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = ProjectTypes::ALLOWED_TYPES.values.map do |i|
          decorator(i, I18n.t("activerecord.attributes.project_type/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def roles
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = User::ROLES.values.map do |i|
          decorator(i, I18n.t("activerecord.attributes.user.role/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def states
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = User.aasm.states.map do |i|
          decorator(i.name, I18n.t("activerecord.attributes.user.state/#{i.name}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def policlinic_kinds
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Policlinic::KINDS.values.map do |i|
          decorator(i, I18n.t("activerecord.attributes.policlinic.kind/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def policlinic_sizes
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Policlinic::SIZES.values.map do |i|
          { id: i, name: I18n.t("activerecord.attributes.policlinic.size/#{i}"), time_to_inspect_minutes: Policlinic::SIZES_TO_MINUTES[i.to_sym] }
        end

        render json: items
      end

      def mfc_divisions
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Mfc::DIVISIONS.map do |i|
          decorator(i, I18n.t("activerecord.attributes.mfc.division/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def mfc_kinds
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Mfc::KINDS.values.map do |i|
          decorator(i, I18n.t("activerecord.attributes.mfc.kind/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def districts
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = District.all

        render partial: 'codebook', locals: { items: items }
      end

      def policlinics
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Policlinic.not_archived

        render partial: 'codebook', locals: { items: items }
      end

      def mfcs
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Mfc.not_archived

        render partial: 'codebook', locals: { items: items }
      end

      def checklists
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Checklist.where(project_type: current_project_type)

        render partial: 'codebook', locals: { items: items }
      end

      def inspection_states
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Inspection.aasm.states.map(&:name).map do |i|
          decorator(i, I18n.t("activerecord.attributes.inspection.state/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def inspection_cancel_reasons
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Inspection::CANCEL_REASONS.keys.map do |i|
          decorator(i, I18n.t("activerecord.attributes.inspection.cancel_reason/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def calendar_day_absence_reasons
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = CalendarDay::EXTENDED_KINDS.keys.map do |i|
          decorator(i, I18n.t("activerecord.attributes.calendar_day.extended_kind/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def report_kinds
        authorize :codebook, (__method__.to_s + '?').to_sym

        items = Report::KINDS.values.map do |i|
          decorator(i, I18n.t("activerecord.attributes.report.kind/#{i}"))
        end

        render partial: 'codebook', locals: { items: items }
      end

      def checklist_parameters
        authorize :codebook, (__method__.to_s + '?').to_sym

        checklist = Checklist.find(params[:checklist_id])

        parameter_ids = Checklists::ExtractParameterIds.call(checklist)
        items = Parameter.where(id: parameter_ids).pluck(:id, :title).map do |i|
          decorator(i[0], i[1])
        end

        render partial: 'codebook', locals: { items: items }
      end

      private

      def decorator(id, name)
        Struct.new(:id, :name).new(id, name)
      end
    end
  end
end
