# frozen_string_literal: true

module Api
  module Admin
    class CriteriaController < BaseController
      before_action :set_criterion, only: %i[show update update_position destroy]

      def index
        authorize :criterion, :index?
        @criteria = CriterionSearcher.call(params, current_user, current_project_type)
        @pagy = Pagy.new_from_searchkick(@criteria)
      end

      def show
        authorize @criterion
      end

      def create
        authorize :criterion, :create?
        result = Criteria::Create.call(criterion_params, current_user)

        if result.success?
          @criterion = result.value!
          render :show, status: :created
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def update
        authorize @criterion

        result = Criteria::Update.call(@criterion, params, current_user)

        if result.success?
          render :show
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def update_position
        authorize @criterion

        @criterion.insert_at(params[:position])

        Criterion.where(project_type: @criterion.project_type).reindex

        head :no_content
      end

      def destroy
        authorize @criterion
        if @criterion.archive
          head 204
        else
          render json: { code: 422, errors: @criterion.errors.full_messages }, status: :unprocessable_entity
        end
      end

      private

      def set_criterion
        @criterion = Criterion.find(params[:id])
      end

      def criterion_params
        params.permit(:title, :project_type, :input_type, select_options: [])
      end
    end
  end
end
