# frozen_string_literal: true

# require 'zip'

module Api
  module Admin
    class FileArchivesController < BaseController
      before_action :set_file_archive, only: %i[show download]

      def index
        authorize :file_archive, :index?
        @file_archives = FileArchiveSearcher.call(params, current_user, current_project_type)

        @pagy = Pagy.new_from_searchkick(@file_archives)
      end

      def show
        @file_names = Inspections::ExtractFileParameterTitles.call(@file_archive)
        authorize @file_archive
      end

      def download
        authorize @file_archive

        path = Rails.root.join("tmp/file_archives/#{@file_archive.id}/Медиафайлы_по_проверке_id_#{@file_archive.id}.zip")

        if File.exist?(path)
          send_file(path, type: 'application/zip', disposition: :attachment, filename: File.basename(path))
        else
          BuildZipFileJob.perform_later(@file_archive.id, current_user)
          render json: { file_archive_id: @file_archive.id }, status: :accepted
        end
      end

      private

      def set_file_archive
        @file_archive = Inspection.find(params[:id])
      end
    end
  end
end
