# frozen_string_literal: true

module Api
  module Admin
    class InspectionSchedulesController < BaseController
      before_action :set_calendar_month

      def show
        authorize :inspection_schedule, :show?
        user_by_project_type_ids = User.inspector.with_archived_by(@date).where(project_type: current_project_type).pluck(:id)
        user_with_planned_inspections_ids = User.inspector.with_archived_by(@date)
                                                .includes(inspections: [calendar_day: :calendar_month])
                                                .where(calendar_months: { project_type: current_project_type }).pluck(:id)
        @users = User.where(id: user_by_project_type_ids + user_with_planned_inspections_ids)
        @users = @users.where(curator: current_user) if current_user.curator?
        @calendar_days = @calendar_month.calendar_days.includes(inspections: %i[checklist inspectable inspector]).group_by(&:user_id)
        render 'api/admin/schedules/show'
      end

      def create
        authorize :inspection_schedule, :create?
        if current_project_type != ProjectTypes::ALLOWED_TYPES[:policlinic]
          return render json: { code: 422, errors: { message: [I18n.t('errors.schedule.cannot_create_for_this_project')] } },
                        status: :unprocessable_entity
        end

        @checklist = Checklist.policlinic.find(params[:checklist_id])
        job_id = InspectionSchedules::CreateJob.perform_later(@calendar_month, current_user, @checklist).job_id
        render json: { code: 202, job_id: job_id }, status: :accepted
      end

      def destroy
        authorize :inspection_schedule, :destroy?
        job_id = InspectionSchedules::CleanJob.perform_later(@calendar_month, current_user).job_id
        render json: { code: 202, job_id: job_id }, status: :accepted
      end

      private

      def set_calendar_month
        @date = begin
                  Date.strptime(params[:month], '%Y-%m')
                rescue StandardError
                  raise ActiveRecord::RecordNotFound
                end

        @calendar_month = CalendarMonth.find_or_initialize_by(date: @date, project_type: current_project_type)
        @calendar_month.save! if @calendar_month.new_record? && action_name != 'show'
      end
    end
  end
end
