# frozen_string_literal: true

module Api
  module Admin
    class InspectionsController < BaseController
      before_action :set_inspection, only: %i[show update]
      before_action :set_inspections, only: %i[cancel mass_destroy]

      def index
        authorize :inspection, :index?
        @inspections = InspectionSearcher.call(params, current_user, current_project_type)
        @pagy = Pagy.new_from_searchkick(@inspections)
      end

      def show
        authorize @inspection
      end

      def create
        authorize :inspection, :create?
        result = Inspections::Create.call(params, current_user)

        if result.success?
          @inspection = result.value!
          render :show, status: :created
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def update
        authorize @inspection
        result = Inspections::Update.call(@inspection, params, current_user)

        if result.success?
          render :show
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def cancel
        authorize :inspection, :cancel?

        result = Inspections::Cancel.call(@inspections, cancel_reason: params[:cancel_reason])

        render json: { code: 422, errors: result.failure }, status: :unprocessable_entity if result.failure?
      end

      def mass_destroy
        authorize :inspection, :mass_destroy?

        result = Inspections::Destroy.call(@inspections)

        if result.success?
          head 204
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      private

      def set_inspection
        @inspection = Inspection.find(params[:id])
      end

      def set_inspections
        @inspections = Inspection.where(id: params[:inspection_ids])
      end
    end
  end
end
