# frozen_string_literal: true

module Api
  module Admin
    class MfcsController < BaseController
      before_action :set_mfc, only: %i[show update destroy]

      def index
        @mfcs = MfcSearcher.call(params, current_user)
        @pagy = Pagy.new_from_searchkick(@mfcs)
        authorize :mfc, :index?
      end

      def show
        authorize @mfc
      end

      def create
        authorize :mfc, :create?
        @mfc = Mfc.create(mfc_params)

        if @mfc.persisted?
          render :show, status: :created
        else
          render json: { code: 422, errors: @mfc.errors }, status: :unprocessable_entity
        end
      end

      def update
        authorize @mfc

        if @mfc.update(mfc_params)
          render :show
        else
          render json: { code: 422, errors: @mfc.errors }, status: :unprocessable_entity
        end
      end

      def destroy
        authorize @mfc

        result = ArchiveInspectable.call(@mfc)

        render json: { code: 422, errors: result.failure }, status: :unprocessable_entity unless result.success?
      end

      private

      def set_mfc
        @mfc = Mfc.find(params[:id])
      end

      def mfc_params
        params.permit(:name, :district_id, :address, :division, :kind, :comment, :latitude, :longitude, :territory_id)
      end
    end
  end
end
