# frozen_string_literal: true

module Api
  module Admin
    class NonWorkingDaysController < BaseController
      before_action :set_non_working_day, only: %i[show destroy]

      def index
        authorize :non_working_day, :index?
        scope = NonWorkingDay.all
        scope = scope.order(date: sortings['date']) if sortings['date'].in?(BaseSearcher::ALLOWED_SORTING_VALUES)
        @pagy, @non_working_days = pagy(scope, items: params[:per_page])
      end

      def show
        authorize @non_working_day
      end

      def create
        authorize :non_working_day, :create?
        @non_working_day = NonWorkingDay.create(non_working_day_params)

        if @non_working_day.persisted?
          render :show, status: :created
        else
          render json: { code: 422, errors: @non_working_day.errors }, status: :unprocessable_entity
        end
      end

      def destroy
        authorize @non_working_day
        @non_working_day.destroy
        head :no_content
      end

      private

      def set_non_working_day
        @non_working_day = NonWorkingDay.find(params[:id])
      end

      def non_working_day_params
        params.permit(:date)
      end
    end
  end
end
