# frozen_string_literal: true

module Api
  module Admin
    class ObjectSchedulesController < BaseController
      before_action :set_calendar_month

      def show
        authorize :object_schedule, :show?
        @objects = current_project_type.camelize.constantize.not_archived
        @inspections = @calendar_month.inspections.visible.includes(%i[checklist inspectable inspector]).group_by(&:inspectable_id)
      end

      private

      def set_calendar_month
        @date = begin
                  Date.strptime(params[:month], '%Y-%m')
                rescue StandardError
                  raise ActiveRecord::RecordNotFound
                end

        @calendar_month = CalendarMonth.find_or_initialize_by(date: @date, project_type: current_project_type)
        @calendar_month.save! if @calendar_month.new_record? && action_name != 'show'
      end
    end
  end
end
