# frozen_string_literal: true

module Api
  module Admin
    class PoliclinicsController < BaseController
      before_action :set_policlinic, only: %i[show update destroy]

      def index
        @policlinics = PoliclinicSearcher.call(params, current_user)
        @pagy = Pagy.new_from_searchkick(@policlinics)
        authorize @policlinics
      end

      def show
        authorize @policlinic
      end

      def create
        authorize :policlinic, :create?
        @policlinic = Policlinic.create(policlinic_params)

        if @policlinic.persisted?
          render :show, status: :created
        else
          render json: { code: 422, errors: @policlinic.errors }, status: :unprocessable_entity
        end
      end

      def update
        # TODO: cannot edit if policlinic is assigned to any inspection(?)
        # absolutely retarded case, awaiting confirmation from Alya/Anton
        authorize @policlinic

        if @policlinic.update(policlinic_params)
          render :show
        else
          render json: { code: 422, errors: @policlinic.errors }, status: :unprocessable_entity
        end
      end

      def destroy
        authorize @policlinic

        result = ArchiveInspectable.call(@policlinic)

        render json: { code: 422, errors: result.failure }, status: :unprocessable_entity unless result.success?
      end

      private

      def set_policlinic
        @policlinic = Policlinic.find(params[:id])
      end

      def policlinic_params
        params.permit(:name, :district_id, :address, :latitude, :longitude, :population, :floors, :kind, :size, :comment, :time_to_inspect_minutes)
      end
    end
  end
end
