# frozen_string_literal: true

module Api
  module Admin
    class RepairPeriodsController < BaseController
      before_action :set_repair_period, only: %i[update destroy]

      def create
        authorize :repair_period, :create?
        @repair_period = RepairPeriod.create(repair_period_params)

        if @repair_period.persisted?
          render json: @repair_period.as_json(only: %i[id starts_at ends_at]), status: :created
        else
          render json: { code: 422, errors: @repair_period.errors }, status: :unprocessable_entity
        end
      end

      def update
        authorize @repair_period

        if @repair_period.update(repair_period_params)
          render json: @repair_period.as_json(only: %i[id starts_at ends_at])
        else
          render json: { code: 422, errors: @repair_period.errors }, status: :unprocessable_entity
        end
      end

      def destroy
        authorize @repair_period

        if @repair_period.destroy
          head :no_content
        else
          render json: { code: 422, errors: @repair_period.errors.full_messages }, status: :unprocessable_entity
        end
      end

      private

      def set_repair_period
        @repair_period = RepairPeriod.find(params[:id])
      end

      def repair_period_params
        pp = params.permit(:starts_at, :ends_at, :repairable_id, :repairable_type)
        pp[:repairable_type]&.capitalize!
        pp
      end
    end
  end
end
