# frozen_string_literal: true

module Api
  module Admin
    class ReportsController < BaseController
      before_action :set_report, only: %i[show]

      def index
        authorize :report, :index?
        @reports = ReportSearcher.call(params, current_user, current_project_type)
        @pagy = Pagy.new_from_searchkick(@reports)
      end

      def show
        authorize @report

        filename = "revizor-report-#{@report.project_type}-#{@report.kind}-created-#{@report.created_at}.xlsx"
        tempfile = Tempfile.new(filename)

        data = ReportMatrix.from_json(@report.serialized_report_matrix)

        WriteXlsxMatrix.call(data, tempfile)

        send_file(tempfile, filename: filename)

        tempfile.close
      end

      def create
        authorize :report, :create?

        matrix = GenerateReportMatrix.call(Date.parse(params[:date]), current_project_type)
        # TODO: generate in the background
        @report = Report.new(report_params.merge(project_type: current_project_type, state: :generated, serialized_report_matrix: matrix.to_json))

        if @report.save
          render json: @report.to_json(only: %i[id created_at kind state]), status: :created
        else
          render json: { code: 422, errors: @report.errors }, status: :unprocessable_entity
        end
      end

      private

      def set_report
        @report = Report.find(params[:id])
      end

      def report_params
        params.permit(:kind)
      end
    end
  end
end
