# frozen_string_literal: true

module Api
  module Admin
    class VacationsController < BaseController
      before_action :set_vacation, only: %i[show update destroy]
      before_action :set_target_user, only: %i[create update]

      def index
        @vacations = VacationSearcher.call(params, current_user, current_project_type)
        @pagy = Pagy.new_from_searchkick(@vacations)
        authorize :vacation, :index?
      end

      def show
        authorize @vacation
      end

      def create
        authorize :vacation, :create?

        result = Vacations::Create.call(current_user, @target_user, vacation_params)

        if result.success?
          @vacation = result.value!
          render :show, status: :created
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def update
        authorize @vacation

        result = Vacations::Update.call(@target_user, @vacation, vacation_params)

        if result.success?
          render :show
        else
          render json: { code: 422, errors: result.failure }, status: :unprocessable_entity
        end
      end

      def destroy
        authorize @vacation

        if @vacation.destroy
          head 204
        else
          render json: { code: 422, errors: vacation.errors.full_messages }, status: :unprocessable_entity
        end
      end

      private

      def set_vacation
        @vacation = Vacation.find(params[:id])
      end

      def vacation_params
        params.permit(:starts_at, :ends_at, :user_id)
      end

      def set_target_user
        @target_user = User.find(params[:user_id])
      end
    end
  end
end
