# frozen_string_literal: true

module Api
  module Admin
    class WorkingNormsController < BaseController
      before_action :set_working_norm, only: %i[show update]

      def index
        authorize :working_norm, :index?
        @pagy, @working_norms = pagy(WorkingNorm.all, items: params[:per_page])
      end

      def show
        authorize @working_norm
      end

      def create
        authorize :working_norm, :create?
        @working_norm = WorkingNorm.create(working_norm_params)

        if @working_norm.persisted?
          render :show, status: :created
        else
          render json: { code: 422, errors: @working_norm.errors }, status: :unprocessable_entity
        end
      end

      def update
        authorize @working_norm

        if @working_norm.update(working_norm_params)
          render :show
        else
          render json: { code: 422, errors: @working_norm.errors }, status: :unprocessable_entity
        end
      end

      private

      def set_working_norm
        @working_norm = WorkingNorm.find(params[:id])
      end

      def working_norm_params
        pp = params.permit(:date)
        pp[:hours] = params[:working_hours_norms]
        pp
      end
    end
  end
end
