# frozen_string_literal: true

module Api
  module Auth
    class SessionsController < BaseController
      before_action :authorize_by_access_cookie!, only: :destroy
      before_action :authorize_refresh_by_access_cookie!, only: :refresh
      skip_after_action :verify_authorized

      def create
        user = User.not_archived.find_by(email: params[:email]&.strip&.downcase)
        if user&.authenticate(params[:password]&.strip)
          tokens = JWTSessions::Session.new(payload: { user_id: user.id }, refresh_by_access_allowed: true).login
          set_access_cookie(tokens)
          @user = user
          @csrf = tokens[:csrf]
          user.update(last_sign_in_at: Time.current)
        else
          render json: { code: 401, errors: { message: [I18n.t('errors.auth.invalid_email_or_password')] } }, status: :unauthorized
        end
      end

      def refresh
        jwt_session = JWTSessions::Session.new(payload: claimless_payload, refresh_by_access_allowed: true)
        tokens = jwt_session.refresh_by_access_payload do
          raise JWTSessions::Errors::Unauthorized, 'Malicious activity detected'
        end
        set_access_cookie(tokens)
        render json: { csrf: tokens[:csrf] }
      end

      def destroy
        jwt_session = JWTSessions::Session.new(payload: payload)
        jwt_session.flush_by_access_payload
        response.cookies.delete(JWTSessions.access_cookie)
        render json: { code: 200 }, status: :ok
      end
    end
  end
end
