# frozen_string_literal: true

module Api
  class ChecklistsController < ApplicationController
    skip_before_action :authorize_by_access_cookie!
    skip_after_action :verify_authorized

    before_action :set_checklist

    def show
      render json: @checklist.raw_data
    end

    def update
      if @checklist.update(raw_data: params[:raw_data])
        render json: @checklist.raw_data
      else
        render json: { errors: @checklist.errors }, status: :unprocessable_entity
      end
    end

    # resets the state to initial
    def destroy
      initial_state = File.read(Rails.root.join("db/seeds/#{params[:project]}.json"))

      if @checklist.update(raw_data: initial_state)
        render json: @checklist.raw_data
      else
        render json: { errors: @checklist.errors }, status: :unprocessable_entity
      end
    end

    private

    def set_checklist
      # mock checklist until we setup user/registration and can move to a proper structure
      @checklist = Checklist.where(project_type: params[:project]).first
    end
  end
end
