# frozen_string_literal: true

class CalendarDay < ApplicationRecord
  searchkick

  KINDS = {
    working: 'working',
    user_non_working: 'user_non_working',
    vacation: 'vacation'
  }.freeze

  EXTENDED_KINDS = {
    sick: 'sick',
    non_paid_vacation: 'non_paid_vacation',
    extra_vacation: 'extra_vacation'
  }.freeze

  enum kind: KINDS
  enum extended_kind: EXTENDED_KINDS

  belongs_to :calendar_month
  belongs_to :user
  belongs_to :vacation, optional: true

  has_many :inspections, dependent: :destroy
  has_many :visible_inspections, -> { visible }, class_name: 'Inspection', inverse_of: :calendar_day

  validates :date, presence: true, uniqueness: { scope: :user_id }
  validates :working_hours, inclusion: { in: 0..12 }
  validate :ensure_not_sunday, if: -> { working? }

  private

  def ensure_not_sunday
    errors.add(:date, I18n.t('errors.calendar_day.date.cant_be_sunday')) if date&.sunday?
  end
end
