# frozen_string_literal: true

class Mfc < ApplicationRecord
  include Archivable

  searchkick

  belongs_to :district
  belongs_to :territory

  has_one :administrative_district, through: :district
  has_many :inspections, as: :inspectable, dependent: :restrict_with_exception
  has_many :repair_periods, as: :repairable, dependent: :restrict_with_exception

  KINDS = { flagman: 'flagman', regular: 'regular' }.freeze
  DIVISIONS = %w[first second third].freeze

  enum kind: KINDS

  validates :name, :address, :division, :kind, :longitude, :latitude, presence: true
  validates :name, uniqueness: true
  validates :division, inclusion: { in: DIVISIONS }

  def search_data
    attributes.merge(
      administrative_district_id: administrative_district.id,
      administrative_district: { name: administrative_district.name },
      territory: { name: territory.name }
    )
  end
end
