# frozen_string_literal: true

class RepairPeriod < ApplicationRecord
  belongs_to :repairable, polymorphic: true

  validate :starts_at_must_be_erlier_than_ends_at
  validate :ensure_no_overlapping
  validates :starts_at, presence: true

  before_validation :set_ends_at

  scope :by_month, ->(date) { where('(?, ?) OVERLAPS (starts_at, ends_at)', date.beginning_of_month, date.end_of_month) }

  private

  def set_ends_at
    self.ends_at = ends_at.end_of_day if ends_at?
  end

  def starts_at_must_be_erlier_than_ends_at
    return if ends_at.blank?

    errors.add(:ends_at, I18n.t('activerecord.errors.messages.ends_at_cannot_be_earlier_than_starts_at')) if starts_at >= ends_at
  end

  def ensure_no_overlapping
    if self.class
           .where.not(id: id)
           .where(repairable: repairable)
           .where("(?, ?) OVERLAPS (starts_at, COALESCE(ends_at, 'infinity'::timestamp))", starts_at, ends_at).exists?
      errors.add(:base, I18n.t('activerecord.errors.messages.overlapping_repair_period'))
    end
  end
end
