# frozen_string_literal: true

class Vacation < ApplicationRecord
  searchkick

  belongs_to :user
  has_many :calendar_days, -> { where(kind: :vacation) }, dependent: :destroy, inverse_of: :vacation

  validate :starts_at_must_be_erlier_than_ends_at
  validates :starts_at, presence: true
  validates :ends_at, presence: true

  def search_data
    attributes.merge(
      user: {
        project_type: user.project_type,
        curator_id: user.curator_id,
        full_name: user.full_name,
        curator: { full_name: user.curator&.full_name }
      }
    )
  end

  private

  def starts_at_must_be_erlier_than_ends_at
    return if ends_at.blank?

    errors.add(:ends_at, I18n.t('activerecord.errors.messages.ends_at_cannot_be_earlier_than_starts_at')) if starts_at >= ends_at
  end
end
