# frozen_string_literal: true

class ArchiveInspectable
  include Dry::Monads[:result, :do]

  static_facade :call
  pattr_initialize :policlinic

  def call
    yield ensure_no_planned_inspections
    yield archive_policlinic

    Success(policlinic)
  end

  private

  def ensure_no_planned_inspections
    if policlinic.inspections.planned.any?
      Failure(message: [I18n.t('errors.cant_archive.inspectable.with_planned_inspections')])
    else
      Success(policlinic)
    end
  end

  def archive_policlinic
    policlinic.archive
    Success(policlinic)
  end
end
