# frozen_string_literal: true

module Criteria
  class Create
    include Dry::Monads[:result, :do]

    static_facade :call
    pattr_initialize :params, :current_user
    attr_accessor :criterion

    def call
      yield authorize_project_type
      yield create_criterion

      Success(criterion)
    end

    private

    def authorize_project_type
      return Success() if current_user.superadmin?
      return Success() if current_user.admin_of_project?(params[:project_type])

      Failure(message: [I18n.t('errors.cant_create.criterion.for_another_project')])
    end

    def create_criterion
      self.criterion = Criterion.new(params)
      return Success(criterion) if criterion.save

      Failure(message: criterion.errors.full_messages)
    end
  end
end
