# frozen_string_literal: true

module Criteria
  class Update
    include Dry::Monads[:result, :do]

    static_facade :call
    pattr_initialize :criterion, :params, :current_user

    def call
      yield authorize_project_type
      yield verify_only_allowed_criterion_type
      yield verify_only_allowed_updates
      yield update_criterion

      Success(criterion)
    end

    private

    def authorize_project_type
      return Success(criterion) if current_user.superadmin?
      return Success(criterion) if current_user.admin_of_project?(params[:project_type])

      Failure(message: [I18n.t('errors.cant_update.criterion.for_another_project')])
    end

    def verify_only_allowed_criterion_type
      return Success(criterion) if criterion.input_type == 'select'

      Failure(message: [I18n.t('errors.cant_update.criterion.type_not_allowed')])
    end

    def verify_only_allowed_updates
      return Success(criterion) if (criterion.select_options - criterion_params[:select_options]).empty?

      Failure(message: [I18n.t('errors.cant_update.criterion.cant_remove_options')])
    end

    def update_criterion
      if criterion.update(criterion_params)
        Success(criterion)
      else
        Failure(message: criterion.errors.full_messages)
      end
    end

    def criterion_params
      params.permit(select_options: [])
    end
  end
end
