# frozen_string_literal: true

module InspectionSchedules
  class Clean
    include Dry::Monads[:result, :do]
    include AfterCommitEverywhere
    include Schedulable

    static_facade :call
    pattr_initialize :calendar_month

    def call # rubocop:disable Metrics/MethodLength
      lock_and_rollback_state_on_fail(calendar_month, ttl: 3.minutes, error_messages: [I18n.t('errors.schedule.cannot_clean')]) do
        yield ensure_not_cleaning_passed_month
        yield start_inspection_schedule_cleaning(calendar_month)
        broadcast_to_subscribers(action: :state_update, calendar_month: calendar_month)

        ActiveRecord::Base.transaction do
          yield destroy_inspections
          yield finish_inspection_schedule_cleaning(calendar_month)

          after_commit do
            broadcast_to_subscribers(action: :reload, calendar_month: calendar_month)
          end
        end
      end
      Success()
    end

    private

    def start_inspection_schedule_cleaning(calendar_month)
      calendar_month.start_inspection_schedule_cleaning!
      Success()
    rescue AASM::InvalidTransition
      Failure(message: [I18n.t('errors.schedule.cannot_clean')])
    end

    def destroy_inspections
      Inspection.where(calendar_day: calendar_month.calendar_days.where(date: available_days)).destroy_all
      Success()
    end

    def finish_inspection_schedule_cleaning(calendar_month)
      calendar_month.finish_inspection_schedule_cleaning!
      Success()
    end
  end
end
