# frozen_string_literal: true

module Inspections
  class Create < Base
    pattr_initialize :params, :current_user

    def call # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
      ActiveRecord::Base.transaction do
        target_inspector = yield authorize_target_inspector
        yield find_checklist
        yield find_inspectable
        yield ensure_inspectable_not_repair
        inspection = yield build_inspection
        calendar_day = yield (target_inspector.curator? ? find_or_create_calendar_day(inspection.date) : find_calendar_day(inspection.date))
        yield verify_project_type(:create)
        yield verify_checklist
        yield persist(calendar_day)

        after_commit do
          broadcast_to_admins(action: 'inspections_create', inspection: inspection)
          broadcast_to_curator(action: 'inspections_create', inspection: inspection, curator_id: inspection.inspector.curator_id)
        end
      end

      Success(inspection)
    end

    private

    attr_accessor :calendar_day, :inspectable, :inspection, :checklist

    def build_inspection
      self.inspection = inspectable.inspections.new(permitted_params)
      Success(inspection)
    end
  end
end
