# frozen_string_literal: true

module Inspections
  class Destroy < Base
    def initialize(inspections)
      @inspections = inspections.respond_to?(:each) ? inspections : [inspections]
    end

    def call
      ActiveRecord::Base.transaction do
        yield destroy_inspections
        yield broadcast_changes
      end

      Success()
    end

    private

    attr_reader :inspections

    def destroy_inspections
      inspections.each do |inspection|
        inspection.destroy! if inspection.planned?
      end
      Success()
    end

    def broadcast_changes
      inspections.each do |inspection|
        broadcast_to_admins(action: 'inspections_delete', inspection: inspection)
        broadcast_to_curator(action: 'inspections_delete', inspection: inspection, curator_id: inspection.inspector.curator_id)
      end

      Success()
    end
  end
end
