# frozen_string_literal: true

module Inspections
  class ExtractFileParameterTitles
    static_facade :call
    pattr_initialize :inspection

    def call # rubocop:disable Metrics/CyclomaticComplexity, Metrics/MethodLength, Metrics/PerceivedComplexity, Metrics/AbcSize
      return {} if inspection.raw_data.blank?

      parsed_inspection_raw_data = JSON[inspection.raw_data]

      file_keys = {}

      parsed_inspection_raw_data['files']&.each do |file|
        file_keys[file['id']] = file['key']
      end

      # file.key => parameter.title
      file_titles = {}

      parsed_inspection_raw_data['blocks']&.each do |raw_block|
        raw_block['groups']&.each do |raw_group|
          raw_group['parameters']&.each do |raw_parameter|
            if raw_parameter['issue'] == 'failed'
              raw_parameter['issues']&.each do |raw_issue|
                raw_issue['photos']&.each do |photo|
                  file_titles[file_keys[photo]] = raw_parameter['title']
                end

                raw_issue['audios']&.each do |audio|
                  file_titles[file_keys[audio]] = raw_parameter['title']
                end

                raw_issue['videos']&.each do |video|
                  file_titles[file_keys[video]] = raw_parameter['title']
                end
              end
            end
          end
        end
      end

      file_titles
    end
  end
end
