# frozen_string_literal: true

module Inspections
  class Update < Base
    pattr_initialize :inspection, :params, :current_user

    def call # rubocop:disable Metrics/MethodLength, Metrics/AbcSize
      ActiveRecord::Base.transaction do
        target_inspector = yield authorize_target_inspector
        yield find_checklist
        yield find_inspectable
        yield ensure_inspectable_not_repair
        yield assign_attributes
        calendar_day = yield (target_inspector.curator? ? find_or_create_calendar_day(inspection.date) : find_calendar_day(inspection.date))
        yield verify_project_type(:update)
        yield verify_checklist
        prev_inspector = inspection.inspector
        yield persist(calendar_day)

        after_commit do
          broadcast_to_admins(action: 'inspections_update', inspection: inspection)
          broadcast_to_curator_on_update(prev_inspector)
        end
      end

      Success(inspection)
    end

    private

    attr_accessor :calendar_day, :inspectable, :checklist

    def broadcast_to_curator_on_update(prev_inspector)
      if inspection.saved_change_to_inspector_id?
        broadcast_to_curator(action: 'inspections_delete', inspection: inspection, curator_id: prev_inspector.curator_id)
        broadcast_to_curator(action: 'inspections_create', inspection: inspection, curator_id: inspection.inspector.curator_id)
      else
        broadcast_to_curator(action: 'inspections_update', inspection: inspection, curator_id: inspection.inspector.curator_id)
      end
    end

    def assign_attributes
      inspection.assign_attributes(permitted_params.merge(inspectable: inspectable))
      Success(inspection)
    end
  end
end
