# frozen_string_literal: true

module Inspections
  class UpdateByInspector < Base
    pattr_initialize :inspection, :params, :current_user

    def call
      ActiveRecord::Base.transaction do
        yield update_inspection

        after_commit do
          broadcast_to_admins(action: 'inspections_update', inspection: inspection)
          broadcast_to_curator(action: 'inspections_update', inspection: inspection, curator_id: inspection.inspector.curator_id)
        end
      end

      Success(inspection)
    end

    private

    def update_inspection
      if inspection.update(params)
        Success(inspection)
      else
        Failure(message: inspection.errors.full_messages)
      end
    end
  end
end
