# frozen_string_literal: true

module Users
  class Archive
    include Dry::Monads[:result, :do]

    static_facade :call
    pattr_initialize :user

    def call
      ActiveRecord::Base.transaction do
        yield ensure_no_subordinate_inspectors if user.curator?
        yield ensure_not_superadmin
        yield cancel_planned_inspections
        yield archive_user
      end

      Success(user)
    end

    private

    def ensure_no_subordinate_inspectors
      if user.inspectors.any?
        Failure(message: [I18n.t('errors.cant_archive.user.curator_with_subordinates')])
      else
        Success(user)
      end
    end

    def ensure_not_superadmin
      if user.superadmin?
        Failure(message: [I18n.t('errors.cant_archive.user.superadmin')])
      else
        Success(user)
      end
    end

    def cancel_planned_inspections
      # TODO: add background job
      user.inspections.planned.each { |inspection| Inspections::Cancel.call(inspection) }
      Success(user)
    end

    def archive_user
      user.archived_at = Time.current
      user.archive!
      Success(user)
    rescue AASM::InvalidTransition
      Failure(message: [I18n.t('errors.cant_archive.user.already_archived')])
    end
  end
end
