# frozen_string_literal: true

module Users
  class Base
    include Dry::Monads[:result, :do]

    static_facade :call

    private

    def superadmin?
      current_user.superadmin?
    end

    def verify_project_type(operation_name)
      return Success() if operation_name == :update && params[:project_type].nil? # handle unchanged project_type on update
      unless current_user.project_type == params[:project_type]
        return Failure(message: [I18n.t("errors.cant_#{operation_name}.user.for_another_project")])
      end

      Success()
    end

    def verify_target_role(operation_name)
      return Success() if operation_name == :update && params[:role].nil? # handle unchanged role on update
      unless allowed_roles.include?(params[:role])
        return Failure(message: [I18n.t("errors.cant_#{operation_name}.user.with_escalated_privileges", role: params[:role])])
      end

      Success()
    end

    def allowed_roles
      case current_user.role
      when 'superadmin' then %w[superadmin admin curator inspector]
      when 'admin'      then %w[curator inspector]
      when 'curator'    then %w[inspector]
      else []
      end
    end
  end
end
