# frozen_string_literal: true

module Users
  class Create < Base
    include AfterCommitEverywhere

    static_facade :call
    pattr_initialize :params, :current_user
    attr_accessor :user

    def call
      yield verify_project_type(:create) unless superadmin?
      yield verify_target_role(:create)
      yield nullify_email

      ActiveRecord::Base.transaction do
        yield create_user

        after_commit do
          yield send_email
        end
      end

      Success(user)
    end

    private

    def nullify_email
      archived_user = User.find_by(state: :archived, email: params[:email])

      if archived_user.present?
        return Failure(message: archived_user.errors.full_messages) unless archived_user.update(email: nil)
      end

      Success(user)
    end

    def create_user
      self.user = User.new(params)
      user.set_password
      if user.save
        Success(user)
      else
        Failure(message: user.errors.full_messages)
      end
    end

    def send_email
      ::Auth::PasswordsMailer.invite(user).deliver_later
      Success(user)
    end
  end
end
