# frozen_string_literal: true

module Users
  class Update < Base
    include AfterCommitEverywhere

    static_facade :call
    pattr_initialize :user, :params, :current_user

    def call
      yield verify_project_type(:update) unless superadmin?
      yield verify_target_role(:update)

      ActiveRecord::Base.transaction do
        yield update_user
        after_commit do
          yield send_email if retry_invite_email?
        end
      end

      Success(user)
    end

    private

    def update_user
      return Success(user) if user.update(params)

      Failure(message: user.errors.full_messages)
    end

    def retry_invite_email?
      user.invited? && user.email_previously_changed?
    end

    def send_email
      ::Auth::PasswordsMailer.invite(user).deliver

      Success(user)
    end
  end
end
