# frozen_string_literal: true

class UserSearcher < BaseSearcher
  includes :curator

  filter :role,         Array
  filter :curator_id,   Array
  filter :state,        Array
  filter :project_type, Array
  filter :id,           Array

  sorting :id
  sorting :full_name
  sorting :role
  sorting :email
  sorting :last_sign_in_at
  sorting :'curator.full_name'

  search_fields :full_name

  def apply_base_scope
    where[:state] = { not: :archived } if where['state'].blank?
  end

  def after_filter
    scope = if current_user.superadmin?
              { project_type: ProjectTypes::ALLOWED_TYPES.values }
            elsif current_user.admin?
              { project_type: current_project_type }
            elsif current_user.curator?
              { curator_id: current_user.id }
            end

    where[:_and] = [scope]
  end
end
