# frozen_string_literal: true

class Seeder
  %w[administrative_districts districts policlinics working_norms non_working_days criteria].each do |resource_name|
    define_method("create_#{resource_name}") { find_or_create_seeds_for(resource_name) }
  end

  private

  def find_or_create_seeds_for(resource_name)
    klass = resource_name.singularize.camelize.constantize
    YAML.load_file(Rails.root.join('db', 'seeds', "#{resource_name}.yml")).each do |attributes|
      record = klass.find_or_initialize_by(id: attributes['id'])
      record.update!(attributes)
    end
    ActiveRecord::Base.connection.reset_pk_sequence!(resource_name)
    klass.reindex if klass.respond_to?(:reindex)
  end
end
