# frozen_string_literal: true

require_relative 'seeder'

seeder = Seeder.new
seeder.create_administrative_districts
seeder.create_districts
seeder.create_policlinics
seeder.create_working_norms
seeder.create_non_working_days
seeder.create_criteria

# TODO: mock checklists, remove when we have proper structure
mfc_data = File.read(Rails.root.join('db/seeds/mfc.json'))
Checklist.create!(name: 'Checklist 1', raw_data: mfc_data, project_type: 'mfc')
#polyclinic_data = File.read(Rails.root.join('db/seeds/policlinics.json'))
policlinic_data = File.read(Rails.root.join('db/seeds/policlinics_checklist.txt'))
Checklist.create!(name: 'Чеклист поликлиник', raw_data: policlinic_data, project_type: 'policlinic')

# create curators with respective number of inspectors
{ "Чебулаев": 49, "Разумовская": 27, "Бурмакина": 22, "Хмелевской": 18 }.each do |last_name, inspector_count|
  gender = %w[male female].sample
  curator = User.create!(
    first_name: Faker::Name.send("#{gender}_first_name".to_sym),
    middle_name: Faker::Name.send("#{gender}_middle_name".to_sym),
    last_name: last_name,
    email: Faker::Internet.unique.email,
    role: :curator,
    project_type: :policlinic,
    password: 'password',
    state: :registered,
    gender: gender
  )

  inspector_count.times do
    gender = %w[male female].sample
    User.create!(
      first_name: Faker::Name.send("#{gender}_first_name".to_sym),
      middle_name: Faker::Name.send("#{gender}_middle_name".to_sym),
      last_name: Faker::Name.send("#{gender}_last_name".to_sym),
      email: Faker::Internet.unique.email,
      role: :inspector,
      project_type: :policlinic,
      curator: curator,
      password: 'password',
      state: :registered,
      gender: gender
    )
  end
end
User.curator.first.update(email: 'curator@revizor.test')

# create mfc inspectors
20.times do
  gender = %w[male female].sample
  User.create!(
    first_name: Faker::Name.send("#{gender}_first_name".to_sym),
    middle_name: Faker::Name.send("#{gender}_middle_name".to_sym),
    last_name: Faker::Name.send("#{gender}_last_name".to_sym),
    email: Faker::Internet.unique.email,
    role: :inspector,
    project_type: :mfc,
    password: 'password',
    state: :registered,
    gender: gender
  )
end
User.inspector.where(project_type: :mfc).first.update(email: 'inspector-mfc@revizor.test')

# create admins
%i[mfc policlinic].each do |project_type|
  User.create!(
    first_name: Faker::Name.send('male_first_name'.to_sym),
    middle_name: Faker::Name.send('male_middle_name'.to_sym),
    last_name: Faker::Name.send('male_last_name'.to_sym),
    email: "admin-#{project_type}@revizor.test",
    role: :admin,
    project_type: project_type,
    password: 'password',
    state: :registered,
    gender: :male
  )
end

# create superadmin
User.create!(
  first_name: Faker::Name.send('male_first_name'.to_sym),
  middle_name: Faker::Name.send('male_middle_name'.to_sym),
  last_name: Faker::Name.send('male_last_name'.to_sym),
  email: 'superadmin@revizor.test',
  role: :superadmin,
  project_type: :policlinic,
  password: 'password',
  state: :registered,
  gender: :male
)

Rake::Task['searchkick:reindex:all'].execute
