# frozen_string_literal: true

FactoryBot.define do
  factory :inspection do
    inspectable { |a| a.association(%i[policlinic].sample) }
    starts_at { 2.hours.from_now }
    ends_at { 4.hours.from_now }
    date { Date.current }
    checklist
    association :inspector, factory: :user
    calendar_day

    trait :with_files do
      io = Rack::Test::UploadedFile.new(Rails.root.join('spec/support/files/example.png'), 'image/png')
      after(:create) do |i|
        i.files.attach(io: io, filename: Random.uuid + '.png', content_type: 'image/png')
      end
    end

    trait :with_violated_parameter do
      raw_data do
        <<~JSON
          {
            "name": "Тест файлов",
            "startsAt": "2021-03-12T15:00:00.000Z",
            "endsAt": "2021-03-12T16:00:00.000Z",
            "issue": "",
            "projectType": "policlinic",
            "blocks": [
              {
                "title": "Блок с файлами",
                "groups": [
                  {
                    "title": "",
                    "parameters": [
                      {
                        "title": "Нарушение с файлами",
                        "allowMany": true,
                        "allowImage": true,
                        "allowAudio": true,
                        "allowVideo": true,
                        "isImportant": false,
                        "hint": "",
                        "issues": [
                          {
                            "criteria": [],
                            "photos": [],
                            "audios": [],
                            "videos": [],
                            "comment": ""
                          }
                        ],
                        "issueCantEvaulateComment": "",
                        "checkTimeAt": "",
                        "uid": 0,
                        "issue": "failed"
                      }
                    ]
                  }
                ],
                "uid": 632
              }
            ],
            "id": 63013,
            "inspectableName": "ГП 201 ф2",
            "state": "finished",
            "inspectorId": 100,
            "inspectableId": 1,
            "checklistId": 43,
            "files": []
          }
        JSON
      end
    end
  end
end
