# frozen_string_literal: true

FactoryBot.define do
  factory :user do
    curator { nil }
    gender { User::GENDERS.values.sample }
    first_name { Faker::Name.send("#{gender}_first_name".to_sym) }
    middle_name { Faker::Name.send("#{gender}_middle_name".to_sym) }
    last_name { Faker::Name.send("#{gender}_last_name".to_sym) }
    email { Faker::Internet.email }
    phone { Faker::PhoneNumber.numerify('7968#######') }
    role { User::ROLES[:inspector] }
    project_type { ProjectTypes::ALLOWED_TYPES.values.sample }
    password { 'password' }
    last_sign_in_at { Time.current }

    User::ROLES.each do |key, value|
      trait key do
        role { value }
        state { :registered }
        with_curator if value == 'inspector'
      end
    end

    trait :with_curator do
      association :curator, factory: :user
    end

    trait :with_planned_inspections do
      after(:create) do |user|
        create(:inspection, inspector: user)
      end
    end

    trait :with_passed_inspections do
      after(:create) do |user|
        create(:inspection, inspector: user, date: Date.current - 1.day, starts_at: Time.current - 1.day)
      end
    end

    trait :archived do
      state { :archived }
    end
  end
end
