# frozen_string_literal: true

require 'rails_helper'

RSpec.describe Inspection, type: :model do
  it_behaves_like 'ValidFactory'

  describe 'associations' do
    it { is_expected.to belong_to(:inspector).class_name('User') }
    it { is_expected.to belong_to(:inspectable) }
    it { is_expected.to belong_to(:checklist) }
    it { is_expected.to belong_to(:calendar_day) }
  end

  describe 'validations' do
    it 'validates that :starts_at is earlier than :ends_at' do
      inspection = build(:inspection, starts_at: Time.current, ends_at: 1.minute.ago)
      expect(inspection).not_to be_valid
      expect(inspection.errors[:ends_at]).to include(I18n.t('activerecord.errors.messages.ends_at_cannot_be_earlier_than_starts_at'))
    end
  end

  describe 'aasm :state' do
    let(:inspection) { build_stubbed(:inspection) }

    it { is_expected.to transition_from(:planned).to(:started).on_event(:start) }
    it { is_expected.to transition_from(:planned).to(:canceled).on_event(:cancel) }
    it { is_expected.to transition_from(:started).to(:canceled).on_event(:cancel) }
    it { is_expected.to transition_from(:started).to(:finished).on_event(:finish) }
    it { is_expected.to transition_from(:finished).to(:remediation_planned).on_event(:plan_remediation) }
  end
end
