# frozen_string_literal: true

require 'rails_helper'

RSpec.describe Policlinic, type: :model do
  it_behaves_like 'ValidFactory'
  it_behaves_like 'Archivable'

  it { is_expected.to define_enum_for(:size).with_values(Policlinic::SIZES).backed_by_column_of_type(:string) }
  it { is_expected.to define_enum_for(:kind).with_values(Policlinic::KINDS).backed_by_column_of_type(:string) }

  describe 'associations' do
    it { is_expected.to belong_to(:district) }

    it { is_expected.to have_one(:administrative_district).through(:district) }
    it { is_expected.to have_many(:inspections) }
    it { is_expected.to have_many(:repair_periods) }
  end

  describe 'validations' do
    subject { create(:policlinic) }

    it { is_expected.to validate_presence_of(:name) }
    it { is_expected.to validate_presence_of(:address) }
    it { is_expected.to validate_presence_of(:longitude) }
    it { is_expected.to validate_presence_of(:latitude) }
    it { is_expected.to validate_presence_of(:kind) }
    it { is_expected.to validate_presence_of(:size) }
    it { is_expected.to validate_uniqueness_of(:name) }
    it { is_expected.to validate_numericality_of(:time_to_inspect_minutes).is_greater_than(0) }
  end
end
