# frozen_string_literal: true

require 'rails_helper'

RSpec.describe Vacation, type: :model do
  it_behaves_like 'ValidFactory'

  it { is_expected.to belong_to(:user) }
  it { is_expected.to have_many(:calendar_days) }

  describe 'validations' do
    it 'validates that :starts_at is earlier than :ends_at' do
      inspection = build(:vacation, starts_at: Time.current, ends_at: 1.day.ago)
      expect(inspection).not_to be_valid
      expect(inspection.errors[:ends_at]).to include(I18n.t('activerecord.errors.messages.ends_at_cannot_be_earlier_than_starts_at'))
    end

    it { is_expected.to validate_presence_of(:starts_at) }
    it { is_expected.to validate_presence_of(:ends_at) }
  end
end
