# frozen_string_literal: true

require 'rails_helper'

describe ArchiveInspectable do
  context 'when trying to archive policlinic' do
    subject { described_class.call(policlinic) }

    let_it_be(:policlinic) { create(:policlinic) }

    context 'with future inspections' do
      let!(:inspetion) { create(:inspection, inspectable: policlinic) }

      it { is_expected.to be_failure }

      it 'doesnt archive the policlinic' do
        expect { described_class.call(policlinic) }
          .not_to(change(Policlinic.archived, :count))
      end
    end

    context 'without future inspections' do
      it { is_expected.to be_success }

      it 'archives the policlinic' do
        expect { described_class.call(policlinic) }
          .to(change(Policlinic.archived, :count).by(1))
      end
    end
  end

  context 'when trying to archive mfc' do
    subject { described_class.call(mfc) }

    let_it_be(:mfc) { create(:mfc) }

    context 'with future inspections' do
      let!(:inspetion) { create(:inspection, inspectable: mfc) }

      it { is_expected.to be_failure }

      it 'doesnt archive the mfc' do
        expect { described_class.call(mfc) }
          .not_to(change(Mfc.archived, :count))
      end
    end

    context 'without future inspections' do
      it { is_expected.to be_success }

      it 'archives the mfc' do
        expect { described_class.call(mfc) }
          .to(change(Mfc.archived, :count).by(1))
      end
    end
  end
end
