# frozen_string_literal: true

require 'rails_helper'

describe Checklists::Create do
  subject(:operation) { described_class.call(params, user) }

  context 'when admin of project' do
    let(:user) { build(:user, :admin, :mfc) }
    let(:raw_data) { JSON[{ blocks: [{ title: 'block', groups: [{ title: 'group', parameters: [{ title: 'parameter' }] }] }] }] }
    let(:params) { attributes_for(:checklist, project_type: 'mfc', raw_data: raw_data) }

    it { is_expected.to be_success }

    it 'creates a checklist' do
      expect { operation }
        .to change(Checklist, :count).by(1)
    end

    it 'creates related entities' do
      expect { operation }
        .to change(Block, :count).by(1)
                                 .and change(Group, :count).by(1)
                                                           .and change(Parameter, :count).by(1)
    end

    context 'creating copy of a checklist' do
      let!(:checklist) { operation.value! }
      let(:new_params) { attributes_for(:checklist, project_type: 'mfc', raw_data: checklist.raw_data) }

      it 'creates a checklist' do
        expect { described_class.call(new_params, user) }
          .to change(Checklist, :count).by(1)
      end

      it 'does not create new related entities' do
        expect { described_class.call(new_params, user) }
          .not_to change(Block, :count)
        expect { described_class.call(new_params, user) }
          .not_to change(Group, :count)
        expect { described_class.call(new_params, user) }
          .not_to change(Parameter, :count)
      end
    end
  end

  context 'when admin of another project' do
    let(:user) { build(:user, :admin, :policlinic) }
    let(:params) { attributes_for(:checklist, project_type: 'mfc') }

    it { is_expected.to be_failure }

    it 'does not create a checklist' do
      expect(Checklist.count).to be_zero
    end
  end
end
