# frozen_string_literal: true

require 'rails_helper'

describe Checklists::Update do
  let_it_be(:checklist) { create(:checklist, project_type: 'mfc') }

  subject(:operation) { described_class.call(checklist, params, user) }

  context 'when admin of project updates attributes' do
    let(:user) { build(:user, :admin, :mfc) }
    let(:raw_data) { JSON[{ blocks: [{ title: 'new block', parameters: [{ title: 'new param' }] }] }] }
    let(:params) { { name: 'new name', raw_data: raw_data } }

    it 'updates attributes' do
      expect { operation }.to(change(checklist, :name).and(change(checklist, :raw_data)))
    end

    it 'creates new related entities' do
      expect { described_class.call(checklist, params, user) }
        .to change(Block, :count).by(1)
    end

    context 'when related entity renamed' do
      let(:block) { create(:block) }
      let(:raw_data) { JSON[{ blocks: [{ title: block.title, uid: block.id }] }] }
      let(:checklist) { create(:checklist, project_type: 'mfc', raw_data: raw_data) }
      let(:params) { { raw_data: JSON[{ blocks: [{ title: 'renamed', uid: block.id }] }] } }

      it 'updates related entity' do
        old_title = block.title

        described_class.call(checklist, params, user)

        new_title = block.reload.title

        expect(new_title).not_to eq old_title
      end
    end
  end

  context 'when admin of another project trying to change project_type' do
    let(:user) { build(:user, :admin, :mfc) }
    let(:params) { attributes_for(:checklist, project_type: 'policlinic') }

    it { is_expected.to be_failure }

    it 'does not update a checklist' do
      expect { operation }
        .not_to(change { checklist })
    end
  end
end
