# frozen_string_literal: true

require 'rails_helper'

RSpec.describe Inspections::Cancel do
  describe '.call' do
    subject(:operation) { described_class.call(inspection) }

    let_it_be(:superadmin) { create(:user, :superadmin) }
    let!(:inspection) { create(:inspection, state: :planned) }

    context 'when inspection not started' do
      it { is_expected.to be_success }

      it 'changes the state to canceled' do
        expect { operation }.to change(inspection, :state).from('planned').to('canceled')
      end
    end

    context 'when inspection already canceled or finished' do
      let(:inspection) { create(:inspection, state: :canceled) }

      it { is_expected.to be_success }

      it 'doenst change the state and returns error message' do
        expect { operation }.not_to change(inspection, :state)
      end
    end

    context 'when passed collection of inspections' do
      subject(:operation) { described_class.call(inspections) }

      let!(:inspection_planned) { create(:inspection, state: :planned) }
      let!(:inspection_started) { create(:inspection, state: :started) }
      let!(:inspection_finished) { create(:inspection, state: :finished) }
      let!(:inspection_canceled) { create(:inspection, state: :canceled) }
      let(:inspections) { [inspection_planned, inspection_started, inspection_finished, inspection_canceled] }

      it { is_expected.to be_success }

      it 'does not change states for finished and canceled inspections' do
        expect { operation }.not_to change(inspection_finished, :state)
        expect { operation }.not_to change(inspection_canceled, :state)
      end

      it 'change states for planned and started inspections' do
        expect(inspection_planned.reload).to transition_from(:planned).to(:canceled).on_event(:cancel!)
        expect(inspection_started.reload).to transition_from(:started).to(:canceled).on_event(:cancel!)
      end
    end
  end
end
