# frozen_string_literal: true

require 'rails_helper'

RSpec.describe Inspections::Destroy do
  describe '.call' do
    context 'when passed single inspection' do
      subject(:operation) { described_class.call(inspection) }

      let!(:inspection) { create(:inspection, state: :planned) }

      it { is_expected.to be_success }

      it 'destroy planned inspection' do
        expect { operation }.to(change(Inspection.planned, :count).by(-1))
      end
    end

    context 'when passed collection of inspections' do
      subject(:operation) { described_class.call(inspections) }

      let!(:inspection_planned) { create(:inspection, state: :planned) }
      let!(:inspection_planned_2) { create(:inspection, state: :planned) }
      let!(:inspection_started) { create(:inspection, state: :started) }
      let!(:inspection_finished) { create(:inspection, state: :finished) }
      let!(:inspection_canceled) { create(:inspection, state: :canceled) }
      let!(:inspection_remediation_planned) { create(:inspection, state: :remediation_planned) }
      let(:inspections) do
        [
          inspection_planned,
          inspection_planned_2,
          inspection_started,
          inspection_finished,
          inspection_canceled,
          inspection_remediation_planned
        ]
      end

      it 'does not destroy finished and remediation_planned inspections' do
        expect { operation }.not_to(change(Inspection.finished, :count))
        expect { operation }.not_to(change(Inspection.remediation_planned, :count))
        expect { operation }.not_to(change(Inspection.started, :count))
        expect { operation }.not_to(change(Inspection.canceled, :count))
      end

      it 'destroy planned, started and canceled inspections' do
        expect { operation }.to(change(Inspection.planned, :count).by(-2))
      end

      it 'broadcast changes to admins and curator' do
        expect(ActionCable.server).to receive(:broadcast).exactly(inspections.count).times.and_call_original
        operation
      end
    end
  end
end
