# frozen_string_literal: true

require 'rails_helper'

RSpec.describe ResetPassword do
  subject(:result) { described_class.call(user, params) }

  let(:user) { create(:user, recovery_password_token_sent_at: Time.current, recovery_password_token: 'token' * 7) }
  let(:params) { { password: 'password' } }

  context 'with valid params' do
    it { is_expected.to be_success }

    it 'returns user' do
      expect(result.value!).to be user
    end
  end

  context 'when recovery_password_token is expired' do
    let(:user) { create(:user, recovery_password_token_sent_at: User::RECOVERY_PASSWORD_TOKEN_EXP_TIME.ago, recovery_password_token: 'token' * 7) }

    it { is_expected.to be_failure }

    it 'returns error message' do
      expect(result.failure[:message]).to include(I18n.t('errors.auth.recovery_password_token_expired'))
    end
  end

  context 'with invalid password' do
    let(:params) { { password: 'pass' } }

    it { is_expected.to be_failure }

    it 'returns error message' do
      expect(result.failure[:password]).to include(I18n.t('errors.messages.too_short', count: User::MIN_PASSWORD_LENGTH))
    end
  end
end
