# frozen_string_literal: true

require 'rails_helper'

describe Users::Archive do
  subject { described_class.call(user) }

  context 'when trying to archive superadmin' do
    let(:user) { create(:user, :superadmin) }

    it { is_expected.to be_failure }

    it 'doesnt archive a user' do
      expect { described_class.call(user) }
        .not_to change(User.archived, :count)
    end
  end

  context 'when trying to archive curator' do
    context 'without subordinate inspectors' do
      let(:user) { create(:user, :curator) }

      it { is_expected.to be_success }

      it 'archives the user' do
        expect { described_class.call(user) }
          .to change(user, :state).to('archived')
      end
    end

    context 'with subordinate inspectors' do
      let(:user) { create(:user, :curator, inspectors: [create(:user)]) }

      it { is_expected.to be_failure }

      it 'doesnt archive a user' do
        expect { described_class.call(user) }
          .not_to change(User.archived, :count)
      end
    end
  end

  context 'when trying to archive inspector' do
    let(:user) { create(:user, :inspector) }

    it { is_expected.to be_success }

    context 'with planned inspections' do
      let!(:inspection) { create(:inspection, inspector: user) }

      it 'cancels the inspection' do
        expect { described_class.call(user) }
          .to change(user.inspections.canceled, :count).by(1)
      end
    end

    it 'archives the user' do
      expect { described_class.call(user) }
        .to change(user, :state).to('archived')
      expect(user.reload.archived_at)
        .not_to eq(nil)
    end
  end
end
