# frozen_string_literal: true

require 'rails_helper'

describe Users::MassUpdate do
  describe '.call' do
    subject(:operation) { described_class.call(users, params) }

    context 'when current_user is superadmin' do
      let(:curator) { create(:user, role: 'curator') }
      let(:users) { create_list(:user, 2, :policlinic, :with_planned_inspections, :with_passed_inspections, :with_curator) }
      let(:params) { { project_type: 'mfc', curator_id: curator.id, user_ids: users.map(&:id) } }
      let(:cancel_params) do
        {
          project_type: 'mfc',
          cancel_inspections: true,
          purge_starts_at: Date.current,
          destroy_inspections: false,
          user_ids: users.map(&:id)
        }
      end
      let(:destroy_params) do
        {
          project_type: 'mfc',
          cancel_inspections: false,
          purge_starts_at: Date.current,
          destroy_inspections: true,
          user_ids: users.map(&:id)
        }
      end

      it { is_expected.to be_success }

      it 'updates a user project type' do
        operation
        users.each do |user|
          expect(user.project_type).to eq('mfc')
        end
      end

      it 'updates a user curator' do
        operation
        users.each do |user|
          expect(user.curator.id).to eq(curator.id)
        end
      end

      it 'cancel planned inspections' do
        described_class.call(users, cancel_params)

        users.each do |user|
          expect(user.inspections.future.planned.count).to eq(0)
        end
      end

      it 'destroy planned inspections' do
        described_class.call(users, destroy_params)

        users.each do |user|
          expect(user.inspections.future.count).to eq(0)
        end
      end

      it 'does not purge passed inspections' do
        described_class.call(users, destroy_params)

        users.each do |user|
          expect(user.inspections.past.count).to eq(1)
        end
      end
    end
  end
end
