# frozen_string_literal: true

require 'rails_helper'

RSpec.describe WorkSchedules::Update do
  describe '.call' do
    subject(:operation) { described_class.call(calendar_month, params, superadmin) }

    let(:params) do
      ActionController::Parameters.new(
        month: month,
        calendar_days: [
          { date: '2020-8-8', user_id: user.id, kind: 'working', working_hours: 8.5 },
          { date: '2020-8-8', user_id: mfc_user.id, kind: 'working', working_hours: 8.5 },
          { date: calendar_day1.date, user_id: calendar_day1.user_id, kind: 'working', working_hours: 8.5 },
          { date: calendar_day2.date, user_id: calendar_day2.user_id, kind: 'user_non_working', working_hours: 0 }
        ]
      )
    end
    let(:month) { Date.strptime('2020-8', '%Y-%m') }
    let(:superadmin) { create(:user, :superadmin) }
    let(:user) { create(:user, project_type: calendar_month.project_type) }
    let(:user2) { create(:user, project_type: calendar_month.project_type) }
    let(:mfc_user) { create(:user, project_type: 'mfc') }
    let!(:calendar_month) { create(:calendar_month, date: month, project_type: 'policlinic') }
    let!(:calendar_day1) { create(:calendar_day, user: user, kind: 'user_non_working', working_hours: 0, calendar_month: calendar_month) }
    let!(:calendar_day2) { create(:calendar_day, user: user2, kind: 'working', working_hours: 11.25, calendar_month: calendar_month) }

    let_it_be(:superadmin) { create(:user, :superadmin) }

    context 'with valid params' do
      it { is_expected.to be_success }

      it 'upserts calendar days' do
        expect { operation }.to change(CalendarDay, :count).by(1)
        expect(calendar_day1.reload.kind).to eq 'working'
        expect(calendar_day2.reload.kind).to eq 'user_non_working'
      end
    end
  end
end
