# frozen_string_literal: true

require 'rails_helper'

describe Admin::CriterionPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let(:record) { build(:criterion) }

  context 'as superadmin' do
    let(:user) { build(:user, :superadmin) }

    it { is_expected.to permit_actions %i[index show create update update_position destroy] }
  end

  context 'as project admin' do
    let(:user) { build(:user, :admin, :mfc) }
    let(:record) { build(:criterion, :mfc) }

    it { is_expected.to permit_actions %i[index show create update update_position destroy] }
  end

  context 'as another project admin' do
    let(:user) { build(:user, :admin, :policlinic) }
    let(:record) { build(:criterion, :mfc) }

    it { is_expected.to permit_actions %i[index create] }
    it { is_expected.to forbid_actions %i[show update update_position destroy] }
  end

  context 'as curator' do
    let(:user) { build(:user, :curator, :mfc) }
    let(:record) { build(:criterion, :mfc) }

    it { is_expected.to permit_actions %i[index] }
  end
end
