# frozen_string_literal: true

require 'rails_helper'

describe Admin::InspectionPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let_it_be(:curator) { create(:user, :curator) }
  let_it_be(:inspector) { create(:user, curator: curator) }
  let_it_be(:record) { create(:inspection, inspectable: create(:mfc), inspector: inspector) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions %i[index show create update cancel mass_destroy] }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions %i[index show create update cancel mass_destroy] }
  end

  context 'as a project admin' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'mfc') }

    it { is_expected.to permit_actions %i[index show create update cancel mass_destroy] }
  end

  context 'as another project admin' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'policlinic') }

    it { is_expected.to permit_actions %i[index create] }
    it { is_expected.to forbid_actions %i[show update cancel mass_destroy] }
  end

  context 'as curator' do
    let(:user) { curator }

    it { is_expected.to permit_actions %i[index show create update cancel mass_destroy] }
  end
end
