# frozen_string_literal: true

require 'rails_helper'

describe Admin::MfcPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let_it_be(:record) { create(:mfc) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions(%i[index show create update destroy]) }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions(%i[index show create update destroy]) }
  end

  context 'as an admin of Mfc project' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'mfc') }

    it { is_expected.to permit_actions(%i[index show create update destroy]) }
  end

  context 'as an admin of another project' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'policlinic') }

    it { is_expected.to forbid_actions(%i[index show create update destroy]) }
  end

  context 'as curator' do
    context 'of mfc' do
      let(:user) { build_stubbed(:user, :curator, project_type: 'mfc') }

      it { is_expected.to permit_actions %i[index show] }
      it { is_expected.to forbid_actions(%i[create update destroy]) }
    end

    context 'of policlinic' do
      let(:user) { build_stubbed(:user, :curator, project_type: 'policlinic') }

      it { is_expected.to forbid_actions(%i[index show create update destroy]) }
    end
  end
end
