# frozen_string_literal: true

require 'rails_helper'

describe Admin::NonWorkingDayPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let_it_be(:record) { create(:non_working_day) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions(%i[index show create destroy]) }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions(%i[index show create destroy]) }
  end

  context 'as an admin of any project' do
    let(:user) { build_stubbed(:user, :admin) }

    it { is_expected.to permit_actions(%i[index show create destroy]) }
  end

  context 'as a curator' do
    let(:user) { build(:user, :curator) }

    it { is_expected.to forbid_actions(%i[index show create destroy]) }
  end
end
