# frozen_string_literal: true

require 'rails_helper'

describe Admin::ObjectSchedulePolicy, type: :policy do
  subject { described_class.new(user, nil) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions(%i[show]) }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions(%i[show]) }
  end

  context 'as an admin of Policlinic project' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'policlinic') }

    it { is_expected.to permit_actions(%i[show]) }
  end

  context 'as an admin of Mfc project' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'mfc') }

    it { is_expected.to permit_actions(%i[show]) }
  end

  context 'as a curator of Policlinic project' do
    let(:user) { build(:user, :curator, project_type: 'policlinic') }

    it { is_expected.to forbid_actions(%i[show]) }
  end

  context 'as a curator of Mfc project' do
    let(:user) { build(:user, :curator, project_type: 'mfc') }

    it { is_expected.to forbid_actions(%i[show]) }
  end
end
