# frozen_string_literal: true

require 'rails_helper'

describe Admin::RepairPeriodPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let(:repairable) { build(:mfc) }
  let(:record) { build(:repair_period, repairable: repairable) }

  context 'as superadmin' do
    let(:user) { build(:user, :superadmin) }

    it { is_expected.to permit_actions %i[create update destroy] }
  end

  context 'as a project admin' do
    let(:user) { build(:user, :admin, project_type: 'mfc') }

    it { is_expected.to permit_actions %i[create update destroy] }
  end

  context 'as another project admin' do
    let(:user) { build(:user, :admin, project_type: 'policlinic') }

    it { is_expected.to forbid_actions %i[update destroy] }
  end
end
