# frozen_string_literal: true

require 'rails_helper'

describe Admin::UserPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let_it_be(:record) { create(:user) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions(%i[index show create update destroy]) }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions(%i[index show create update destroy]) }
  end

  context 'as a project admin' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'mfc') }
    let(:record) { build_stubbed(:user, :inspector, project_type: 'mfc') }

    it { is_expected.to permit_actions(%i[index create show update destroy]) }
  end

  context 'as a different project admin' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'mfc') }
    let(:record) { build_stubbed(:user, :inspector, project_type: 'policlinic') }

    it { is_expected.to forbid_actions(%i[show update destroy]) }
    it { is_expected.to permit_actions(%i[index create]) }
  end

  context 'as a curator' do
    let(:user) { create(:user, :curator) }
    let(:record) { create(:user, curator: user) }

    it { is_expected.to forbid_actions(%i[create destroy]) }
    it { is_expected.to permit_actions(%i[index show update]) }
  end
end
