# frozen_string_literal: true

require 'rails_helper'

describe Admin::VacationPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let_it_be(:record) { create(:vacation, user: create(:user, project_type: 'mfc')) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions %i[index create show update destroy] }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions %i[index create show update destroy] }
  end

  context 'as a project admin' do
    let(:user) { build_stubbed(:user, :admin, project_type: 'mfc') }

    it { is_expected.to permit_actions %i[index create show update destroy] }
  end

  context 'as a curator of vacations user' do
    let(:user) { create(:user, :curator) }
    let(:record) { create(:vacation, user: create(:user, curator: user)) }

    it { is_expected.to permit_actions %i[index show update destroy] }
    # TODO
    # it { is_expected.to permit_actions %i[create]}
  end
end
