# frozen_string_literal: true

require 'rails_helper'

describe Admin::WorkingNormPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let_it_be(:record) { build(:calendar_month) }

  context 'as a regular user' do
    let(:user) { build_stubbed(:user) }

    it { is_expected.to forbid_actions %i[index show create update destroy] }
  end

  context 'as a superadmin' do
    let(:user) { build_stubbed(:user, :superadmin) }

    it { is_expected.to permit_actions %i[index show create update destroy] }
  end

  context 'as an admin' do
    let(:user) { build_stubbed(:user, :admin) }

    it { is_expected.to permit_actions %i[index show create update destroy] }
  end
end
