# frozen_string_literal: true

require 'rails_helper'

describe InspectionPolicy, type: :policy do
  subject { described_class.new(user, record) }

  let(:record) { build(:inspection) }

  context 'as inspector' do
    let(:user) { build(:user, :inspector) }

    it { is_expected.to permit_actions %i[index] }
    it { is_expected.to forbid_actions %i[show update attach_file start finish] }
  end

  context 'as inspector of inspection' do
    let(:user) { build(:user, :inspector) }
    let(:record) { build(:inspection, inspector: user) }

    it { is_expected.to permit_actions %i[index show update attach_file start finish] }
  end

  context 'as curator' do
    let(:user) { build(:user, :curator) }
    let(:record) { build(:inspection, inspector: build(:user, curator: user)) }

    it { is_expected.to permit_actions %i[index attach_file purge_file] }
    it { is_expected.to forbid_actions %i[show update start finish] }
  end

  context 'as admin' do
    let(:user) { build(:user, :admin, :mfc) }
    let(:record) { build(:inspection, inspector: build(:user, :inspector, :mfc)) }

    it { is_expected.to permit_actions %i[index attach_file purge_file] }
    it { is_expected.to forbid_actions %i[show update start finish] }
  end
end
