# frozen_string_literal: true

require 'swagger_helper'

describe 'Codebooks API', type: :request, swagger_doc: 'admin-swagger.json' do
  ADMIN_CODEBOOKS_TAG = 'Admin codebooks'

  sign_in_superadmin

  it_behaves_like 'Codebook', for: 'project_types'
  it_behaves_like 'Codebook', for: 'roles'
  it_behaves_like 'Codebook', for: 'states'
  it_behaves_like 'Codebook', for: 'policlinic_kinds'
  it_behaves_like 'Codebook', for: 'mfc_divisions'
  it_behaves_like 'Codebook', for: 'mfc_kinds'
  it_behaves_like 'Codebook', for: 'territories', backed_by_model: :territory
  it_behaves_like 'Codebook', for: 'curators', backed_by_model: %i[user curator]
  it_behaves_like 'Codebook', for: 'districts', backed_by_model: :district
  it_behaves_like 'Codebook', for: 'policlinics', backed_by_model: :policlinic
  it_behaves_like 'Codebook', for: 'mfcs', backed_by_model: :mfc
  it_behaves_like 'Codebook', for: 'checklists', backed_by_model: :checklist
  it_behaves_like 'Codebook', for: 'inspection_states'
  it_behaves_like 'Codebook', for: 'report_kinds'

  path '/codebooks/administrative_districts' do
    get 'Gets administrative districts with districts codebook' do
      include_context 'RequestDefaultParams', ADMIN_CODEBOOKS_TAG

      response 200, 'Codebook found' do
        let!(:district) { create(:district) }

        schema '$ref' => 'swagger/schemas/admin/codebooks/administrative_districts.json'
        run_test!
      end
    end
  end

  path '/codebooks/policlinic_sizes' do
    get 'Gets policlinic sizes with default time to inspect values' do
      include_context 'RequestDefaultParams', ADMIN_CODEBOOKS_TAG

      response 200, 'Codebook found' do
        schema type: :array,
               items: {
                 type: :object,
                 required: %i[id name timeToInspectMinutes],
                 properties: {
                   id: { type: :string },
                   name: { type: :string },
                   timeToInspectMinutes: { type: :integer }
                 }
               }

        run_test!
      end
    end
  end

  path '/codebooks/checklist_parameters/{checklist_id}' do
    parameter name: :checklist_id, in: :path, type: :integer, description: 'ID чеклиста по которому нужно отфильтровать параметры'
    get 'Gets parameters present in specified checklist' do
      include_context 'RequestDefaultParams', ADMIN_CODEBOOKS_TAG
      let(:parameter) { create(:parameter) }
      let!(:checklist) do
        create(
          :checklist,
          raw_data: { blocks: [{ groups: [{ parameters: [{ uid: parameter.id }] }] }] }.to_json,
          project_type: current_user.project_type
        )
      end

      let(:checklist_id) { checklist.id }
      response 200, 'Codebook found' do
        schema '$ref' => 'swagger/schemas/shared/_codebook.json'
        run_test!
      end
    end
  end
end
