# frozen_string_literal: true

require 'swagger_helper'

describe 'Admin File Archives API', type: :request, swagger_doc: 'admin-swagger.json' do
  ADMIN_FILE_ARCHIVES_TAG = 'Admin File Archives'

  sign_in_superadmin

  path '/file_archives' do
    get 'Gets all file archives' do
      include_context 'RequestDefaultParams', ADMIN_FILE_ARCHIVES_TAG
      include_context 'SearchDefaultParams', FileArchiveSearcher

      describe 'pagination' do # rubocop:disable RSpec/EmptyExampleGroup
        response '404', 'Page number overflow' do
          let(:page) { 2 }
          let(:perPage) { 99 }

          before do
            create_list(:inspection, 2, state: :finished, inspectable: create(:policlinic))
            Inspection.reindex
          end

          run_test!
        end
      end

      response 200, 'File archives found' do
        schema '$ref' => 'swagger/schemas/admin/file_archives/index.json'
        run_test!
      end
    end
  end

  path '/file_archives/{id}' do
    parameter name: :id, in: :path, type: :integer

    get 'Gets a file archive by ID' do
      include_context 'RequestDefaultParams', ADMIN_FILE_ARCHIVES_TAG

      it_behaves_like 'Not Found', resource_name: 'File Archive'
      let(:id) { create(:inspection, state: :finished).id }

      response 200, 'File archive found' do
        schema '$ref' => 'swagger/schemas/admin/file_archives/show.json'
        run_test!
      end
    end
  end

  path '/file_archives/{id}/download' do
    parameter name: :id, in: :path, type: :integer

    get 'Starts file generation or downloads a ZIP archive of files, if ready' do
      include_context 'RequestDefaultParams', ADMIN_FILE_ARCHIVES_TAG

      it_behaves_like 'Not Found', resource_name: 'File Archive'
      let(:inspection) { create(:inspection, state: :finished) }
      let(:id) { inspection.id }

      before { Inspection.reindex }

      response 202, 'File generation started' do
        let(:inspection_with_files) { create(:inspection, :with_files, state: :finished) }
        let(:id) { inspection_with_files.id }
        it 'sends file' do |example|
          submit_request(example.metadata)
          # TODO: пока джоба не отработала - файла нет, а она почему-то не отрабатывает в спеке
          #       нужно придумать как это тестить
          # tempfile_path = Rails.root.join("tmp/file_archives/#{id}/Медиафайлы_по_проверке_id_#{id}.zip")
          # expect(response.body).to eq IO.binread(tempfile_path)
          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end
end
