# frozen_string_literal: true

require 'swagger_helper'

describe 'Admin InspectionSchedules API', type: :request, swagger_doc: 'admin-swagger.json' do
  ADMIN_INSPECTION_SCHEDULES_TAG = 'Admin InspectionSchedules'

  sign_in_superadmin

  let(:month) { '2020-8' }
  let!(:calendar_month) { create(:calendar_month, project_type: current_user.project_type, date: Date.strptime(month, '%Y-%m')) }

  path '/inspection_schedules/{month}' do
    parameter name: :month, in: :path, type: :string, example: '2020-8'

    get 'Gets an inspection schedule by month' do
      include_context 'RequestDefaultParams', ADMIN_INSPECTION_SCHEDULES_TAG

      response 200, 'InspectionSchedule found' do
        schema '$ref' => 'swagger/schemas/admin/inspection_schedules/show.json'
        run_test!
      end
    end

    delete 'Cleans an inspection schedule asynchronously' do
      include_context 'RequestDefaultParams', ADMIN_INSPECTION_SCHEDULES_TAG, true

      response 202, 'Action accepted' do
        schema '$ref' => 'swagger/schemas/shared/accepted.json'

        it 'returns a 202 response' do |example|
          expect { submit_request(example.metadata) }
            .to have_enqueued_job(InspectionSchedules::CleanJob).with(calendar_month, current_user)
          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end

  path '/inspection_schedules' do
    post 'Generates an inspection schedule asynchronously' do
      let(:checklist) { create(:checklist, :policlinic) }

      include_context 'RequestDefaultParams', ADMIN_INSPECTION_SCHEDULES_TAG, true
      parameter name: :params, in: :body, schema:     {
        type: :object,
        properties: {
          month: { type: :string, example: '2020-8' },
          checklistId: { type: :integer }
        },
        required: %i[month checklistId]
      }

      let(:params) { { month: month, checklist_id: checklist.id } }

      response 202, 'Action accepted' do
        schema '$ref' => 'swagger/schemas/shared/accepted.json'

        it 'returns a 202 response' do |example|
          expect { submit_request(example.metadata) }
            .to have_enqueued_job(InspectionSchedules::CreateJob).with(calendar_month, current_user, checklist)
          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end
end
