# frozen_string_literal: true

require 'swagger_helper'

describe 'Non Working Days API', type: :request, swagger_doc: 'admin-swagger.json' do
  ADMIN_NON_WORKING_DAYS_TAG = 'Admin Non Working Days'

  sign_in_superadmin

  path '/non_working_days' do
    get 'Gets all non-working days' do
      include_context 'RequestDefaultParams', ADMIN_NON_WORKING_DAYS_TAG
      # include_context 'SearchDefaultParams', NonWorkingDaySearcher
      parameter name: :page, in: :query, type: :integer
      parameter name: :perPage, in: :query, type: :integer, default: Pagy::VARS[:items]
      let(:page) { 1 }
      let(:perPage) { 5 }

      it_behaves_like 'API Paginatable', :non_working_day

      response 200, 'Non working days found' do
        schema '$ref' => 'swagger/schemas/admin/non_working_days/index.json'
        run_test!
      end
    end

    post 'Creates a non-working day' do
      include_context 'RequestDefaultParams', ADMIN_NON_WORKING_DAYS_TAG, true
      parameter name: :params, in: :body, schema: {
        type: :object,
        required: %i[date],
        properties: {
          date: { type: :string, format: :date }
        }
      }

      let(:params) { {} }

      response 201, 'Non-working day created' do
        let(:params) { { date: '2017-07-21' } }

        schema '$ref' => 'swagger/schemas/admin/non_working_days/show.json'

        it 'creates a non-working day' do |example|
          expect { submit_request(example.metadata) }
            .to(change(NonWorkingDay, :count).by(1))

          assert_response_matches_metadata(example.metadata)
        end
      end

      response 422, 'Non-working day not created' do
        let(:params) { { date: '' } }

        schema '$ref' => 'swagger/schemas/shared/failed_create.json'

        it 'does not create  a non-working day' do |example|
          expect { submit_request(example.metadata) }
            .not_to(change(NonWorkingDay, :count))

          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end

  path '/non_working_days/{id}' do
    get 'Gets a non-working day by ID' do
      include_context 'RequestDefaultParams', ADMIN_NON_WORKING_DAYS_TAG
      parameter name: :id, in: :path, type: :integer, default: 1

      it_behaves_like 'Not Found', resource_name: 'NonWorkingDay'
      let(:id) { create(:non_working_day).id }

      response 200, 'Non-working day found' do
        schema '$ref' => 'swagger/schemas/admin/non_working_days/show.json'
        run_test!
      end
    end

    delete 'Deletes a non-working day' do
      include_context 'RequestDefaultParams', ADMIN_NON_WORKING_DAYS_TAG, true
      parameter name: :id, in: :path, type: :integer, default: 1

      it_behaves_like 'Not Found', resource_name: 'NonWorkingDay'
      let!(:id) { create(:non_working_day).id }

      response 204, 'Non-working day deleted' do
        it 'deletes non-working day' do |example|
          expect { submit_request(example.metadata) }
            .to(change(NonWorkingDay, :count).by(-1))
        end
      end
    end
  end
end
