# frozen_string_literal: true

require 'swagger_helper'

describe 'Admin Reports API', type: :request, swagger_doc: 'admin-swagger.json' do
  ADMIN_REPORTS_TAG = 'Admin Reports'

  let_it_be(:report) { create(:report) }

  sign_in_superadmin

  before { Report.reindex }

  path '/reports' do
    get 'Gets reports of your current project_type' do
      include_context 'SearchDefaultParams', ReportSearcher
      include_context 'RequestDefaultParams', ADMIN_REPORTS_TAG

      it_behaves_like 'API Paginatable', :report

      response 200, 'Reports found' do
        schema '$ref' => 'swagger/schemas/admin/reports/index.json'
        run_test!
      end
    end

    post 'Requests a report generation for a given month' do
      include_context 'RequestDefaultParams', ADMIN_REPORTS_TAG, true

      parameter name: :params, in: :body, schema: {
        type: :object,
        required: %i[date kind],
        properties: {
          date: { type: :string, format: :date },
          kind: { type: :string, enum: Report::KINDS.values }
        }
      }

      let(:params) { {} }

      it_behaves_like 'Unprocessable Entity',
                      as: 'Report',
                      with_params: { date: Date.current.to_s, kind: '' },
                      on: :create

      response 201, 'Report created' do
        let(:params) { { date: Date.current.to_s, kind: 'inspections' } }

        schema type: :object,
               required: %i[id createdAt kind state],
               properties: {
                 id: { type: :integer },
                 createdAt: { type: :string, format: :'date-time' },
                 kind: { type: :string },
                 state: { type: :string }
               }

        it 'creates a report' do |example|
          expect { submit_request(example.metadata) }
            .to(change(Report, :count).by(1))

          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end

  path '/reports/{id}' do
    parameter name: :id, in: :path, type: :integer

    get 'Downloads a report in XLSX format' do
      include_context 'RequestDefaultParams', ADMIN_REPORTS_TAG

      let(:id) { create(:report, :with_matrix).id }

      it_behaves_like 'Not Found', resource_name: 'Report'

      response 200, 'Report found' do
        run_test!
      end
    end
  end
end
