# frozen_string_literal: true

require 'swagger_helper'

describe 'Admin WorkSchedules API', type: :request, swagger_doc: 'admin-swagger.json' do
  ADMIN_WORK_SCHEDULES_TAG = 'Admin WorkSchedules'

  sign_in_superadmin

  let(:month) { '2020-8' }
  let!(:calendar_month) { create(:calendar_month, project_type: current_user.project_type, date: Date.strptime(month, '%Y-%m')) }

  path '/work_schedules/{month}' do
    parameter name: :month, in: :path, type: :string, example: '2020-8'

    get 'Gets a work schedule by month' do
      include_context 'RequestDefaultParams', ADMIN_WORK_SCHEDULES_TAG

      response 200, 'WorkSchedule found' do
        schema '$ref' => 'swagger/schemas/admin/work_schedules/show.json'
        run_test!
      end
    end

    put 'Updates a work schedule asynchronously' do
      include_context 'RequestDefaultParams', ADMIN_WORK_SCHEDULES_TAG, true

      parameter name: :params, in: :body, schema: {
        type: :object,
        properties: {
          calendarDays: {
            type: :array,
            items: {
              required: %w[
                userId
                date
                kind
                workingHours
              ],
              properties: {
                userId: {
                  type: 'integer'
                },
                date: {
                  type: 'string'
                },
                kind: {
                  type: 'string'
                },
                workingHours: {
                  type: 'integer'
                }
              }
            }
          }
        }
      }

      let(:params) { {} }

      response 202, 'Action accepted' do
        schema '$ref' => 'swagger/schemas/shared/accepted.json'
        it 'returns a 202 response' do |example|
          expect { submit_request(example.metadata) }
            .to have_enqueued_job(WorkSchedules::UpdateJob).with(calendar_month, params, current_user)
          assert_response_matches_metadata(example.metadata)
        end
      end
    end

    delete 'Cleans a work schedule asynchronously' do
      include_context 'RequestDefaultParams', ADMIN_WORK_SCHEDULES_TAG, true

      response 202, 'Action accepted' do
        schema '$ref' => 'swagger/schemas/shared/accepted.json'

        it 'returns a 202 response' do |example|
          expect { submit_request(example.metadata) }
            .to have_enqueued_job(WorkSchedules::CleanJob).with(calendar_month, current_user)
          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end

  path '/work_schedules' do
    post 'Generates a work schedule asynchronously' do
      include_context 'RequestDefaultParams', ADMIN_WORK_SCHEDULES_TAG, true
      parameter name: :params, in: :body, schema:     {
        type: :object,
        properties: {
          month: { type: :string, example: '2020-8' }
        },
        required: %i[month]
      }

      let(:params) { { month: month } }

      response 202, 'Action accepted' do
        schema '$ref' => 'swagger/schemas/shared/accepted.json'

        it 'returns a 202 response' do |example|
          expect { submit_request(example.metadata) }
            .to have_enqueued_job(WorkSchedules::CreateJob).with(calendar_month, current_user)
          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end
end
