# frozen_string_literal: true

require 'swagger_helper'

describe 'Direct Uploads API', type: :request do
  DIRECT_UPLOADS_TAG = 'Direct Uploads'

  let_it_be(:user) { create(:user, :inspector, :policlinic) }

  before { sign_in user }

  path '/direct_uploads' do
    post 'Creates direct upload' do
      include_context 'RequestDefaultParams', DIRECT_UPLOADS_TAG, true
      parameter name: :params, in: :body, schema: {
        type: :object,
        required: %i[filename byteSize checksum contentType metadata],
        properties: {
          filename: { type: :string },
          byteSize: { type: :integer },
          checksum: { type: :string },
          contentType: { type: :string },
          metadata: { type: :string }
        }
      }

      let(:params) { {} }

      response 200, 'Direct upload created' do
        let(:params) do
          { filename: 'thing', byte_size: 20, checksum: 228, content_type: 'application/json' }
        end

        schema type: :object,
               required: %i[attachableSgid byteSize checksum contentType createdAt directUpload filename key metadata signedId],
               properties: {
                 attachableSgid: { type: :string },
                 byteSize: { type: :integer },
                 checksum: { type: :string },
                 contentType: { type: :string },
                 createdAt: { type: :string, format: :'date-time' },
                 directUpload: {
                   type: :object,
                   required: %i[headers url],
                   properties: {
                     headers: {
                       type: :object,
                       required: %i[contentType],
                       properties: {
                         contentType: { type: :string }
                       }
                     },
                     url: { type: :string }
                   }
                 },
                 filename: { type: :string },
                 id: { type: :integer },
                 key: { type: :string },
                 metadata: { type: :object },
                 signedId: { type: :string }
               }

        it 'creates a blob' do |example|
          expect { submit_request(example.metadata) }
            .to change(ActiveStorage::Blob, :count).by(1)

          assert_response_matches_metadata(example.metadata)
        end
      end
    end
  end
end
