# frozen_string_literal: true

require 'swagger_helper'

describe 'Blobs API', type: :request, swagger_doc: 'misc-swagger.json' do
  BLOBS_TAG = 'ActiveStorage Blobs'

  let_it_be(:user) { create(:user, :inspector, :policlinic) }

  before { sign_in user }

  path '/rails/active_storage/blobs/{signed_id}/{filename}' do
    parameter name: :signed_id, in: :path, type: :string
    parameter name: :filename, in: :path, type: :string, example: 'my_photo.jpg'

    get 'Retrieves a download URL for requested file' do
      include_context 'RequestDefaultParams', BLOBS_TAG

      let!(:blob) { ActiveStorage::Blob.create(filename: 'test', byte_size: 1, checksum: 1, content_type: 'application/json') }
      let!(:signed_id) { blob.signed_id }
      let!(:filename) { blob.filename }

      response '200', 'Requested file found' do
        schema type: :object, required: %i[url], properties: { url: { type: :string } }

        run_test!
      end
    end
  end
end
