# frozen_string_literal: true

require 'rails_helper'

RSpec.describe CalendarDaySearcher do
  let_it_be(:date) { Date.parse('2020-09-10') }
  let_it_be(:user) { create(:user) }
  let_it_be(:calendar_day) { create(:calendar_day, date: 3.days.before(date), kind: 'working', user: user) }
  let_it_be(:searched) { create(:calendar_day, date: date, kind: 'working', user: user) }
  let_it_be(:unrelated) { create(:calendar_day) }
  let_it_be(:default_scoped) { [searched, calendar_day] }

  before_all { CalendarDay.search_index.refresh }

  describe 'default scope' do
    subject(:searcher) { described_class.call(ActionController::Parameters.new, user) }

    it 'works' do
      expect(searcher.size).to eq 2
      expect(searcher).to include(*default_scoped)
    end
  end

  describe 'filtering' do
    context 'by date' do
      subject(:searcher) do
        described_class.call(
          ActionController::Parameters.new(
            filters: [{ field: 'date', range: { gte: 2.days.before(date), lt: 2.days.since(date) } }]
          ),
          user
        )
      end

      it 'works' do
        expect(searcher.size).to eq 1
        expect(searcher).to include(searched)
      end
    end
  end
end
