# frozen_string_literal: true

require 'rails_helper'

describe ChecklistSearcher do
  let_it_be(:current_project_type) { 'mfc' }
  let_it_be(:user) { create(:user, :superadmin) }
  let_it_be(:project_admin) { create(:user, :admin, project_type: 'mfc') }
  let_it_be(:searched) { create(:checklist, project_type: 'mfc') }
  let_it_be(:sorted) { create(:checklist, project_type: 'mfc') }
  let_it_be(:unrelated) { create(:checklist, project_type: 'policlinic') }

  before_all { Checklist.reindex }

  subject(:searcher) { described_class.call(params, user, current_project_type) }

  let(:params) { {} }

  it_behaves_like 'Searchable', fields: %i[name], is_user_required: true, project_type_required: true
  it_behaves_like 'Sortable', fields: %i[created_at], is_user_required: true, project_type_required: true

  describe 'after filter' do
    context 'as admin of project' do
      let(:user) { project_admin }

      it 'filters out unrelated checklists' do
        expect(searcher).to include searched
        expect(searcher).not_to include unrelated
      end
    end
  end
end
