# frozen_string_literal: true

require 'rails_helper'

describe CriterionSearcher do
  let_it_be(:current_project_type) { 'mfc' }
  let_it_be(:user) { create(:user, :superadmin) }
  let_it_be(:searched) { create(:criterion, :mfc) }
  let_it_be(:sorted) { create(:criterion, :mfc) }
  let_it_be(:unrelated) { create(:criterion, :policlinic) }
  let_it_be(:archived) { create(:criterion, archived_at: Time.zone.now) }
  let_it_be(:default_scoped) { [searched] }

  subject(:searcher) { described_class.call(params, user, current_project_type) }

  let(:params) { {} }

  it_behaves_like 'Searchable', fields: %i[title],
                                is_user_required: true,
                                is_default_scoped: true,
                                project_type_required: true

  it_behaves_like 'Sortable', fields: %i[position],
                              is_user_required: true,
                              project_type_required: true

  describe 'base scope' do
    it 'works' do
      expect(searcher.results).to include(searched)
      expect(searcher.results).not_to include(archived)
    end
  end

  describe 'after filter' do
    context 'as project admin' do
      let(:user) { build(:user, :admin, :mfc) }

      it 'filters out unrelated criteria' do
        expect(searcher.results).to include searched
        expect(searcher.results).not_to include unrelated
      end
    end
  end

  describe 'filtering' do
    context 'by project_type' do
      let(:params) { { filters: [{ field: 'project_type', value: [searched.project_type] }] } }

      it 'works' do
        expect(searcher.size).to eq 2
        expect(searcher.results).to match_array [searched, sorted]
      end
    end
  end
end
