# frozen_string_literal: true

require 'rails_helper'

describe MfcSearcher do
  let_it_be(:searched) { create(:mfc, division: 'first', kind: 'flagman') }
  let_it_be(:unrelated) { create(:mfc, division: 'second', kind: 'regular') }

  let_it_be(:default_scoped) { [searched, unrelated] }

  let_it_be(:archived) { create(:mfc, archived_at: Time.zone.now) }

  before_all { Mfc.reindex }

  it_behaves_like 'Searchable', fields: %i[name], is_default_scoped: true

  describe 'base scope' do
    subject(:searcher) { described_class.call }

    it 'works' do
      expect(searcher.results).to include(searched)
      expect(searcher.results).not_to include(archived)
    end
  end

  describe 'filtering' do
    context 'by administrative_district_id' do
      subject(:searcher) do
        described_class.call({ filters: [{ field: 'administrative_district_id', value: [searched.administrative_district.id] }] })
      end

      it 'works' do
        expect(searcher.results).to include searched
        expect(searcher.results).not_to include unrelated
      end
    end

    context 'by territory_id' do
      subject(:searcher) do
        described_class.call({ filters: [{ field: 'territory_id', value: [searched.territory_id] }] })
      end

      it 'works' do
        expect(searcher.results).to include searched
        expect(searcher.results).not_to include unrelated
      end
    end

    context 'by division' do
      subject(:searcher) do
        described_class.call({ filters: [{ field: 'division', value: [searched.division] }] })
      end

      it 'works' do
        expect(searcher.results).to include searched
        expect(searcher.results).not_to include unrelated
      end
    end

    context 'by kind' do
      subject(:searcher) do
        described_class.call({ filters: [{ field: 'kind', value: [searched.kind] }] })
      end

      it 'works' do
        expect(searcher.results).to include searched
        expect(searcher.results).not_to include unrelated
      end
    end
  end

  describe 'sorting' do
    it_behaves_like 'Sortable',
                    fields: %i[id name administrative_district.name territory.name address division kind]
  end
end
