# frozen_string_literal: true

require 'rails_helper'

describe ReportSearcher do
  let_it_be(:current_project_type) { 'mfc' }
  let_it_be(:user) { create(:user, :superadmin) }
  let_it_be(:searched) { create(:report, :mfc, kind: Report::KINDS.values.first) }
  let_it_be(:unrelated) { create(:report, :mfc, kind: Report::KINDS.values.first, created_at: 2.days.ago) }

  before_all { Report.reindex }

  subject(:searcher) { described_class.call(params, user, current_project_type) }

  let(:params) { {} }

  describe 'filtering' do
    context 'by kind' do
      let(:params) { { filters: [{ field: 'kind', value: [searched.kind] }] } }

      it 'works' do
        expect(searcher.size).to eq 2
        expect(searcher.results).to match_array [searched, unrelated]
      end
    end

    context 'by created_at' do
      let(:params) { { filters: [{ field: 'created_at', range: { gte: searched.created_at - 1.day, lte: searched.created_at + 1.day } }] } }

      it 'works' do
        expect(searcher.size).to eq 1
        expect(searcher.results.first).to eq searched
      end
    end
  end
end
