# frozen_string_literal: true

module RequestMacros
  extend ActiveSupport::Concern

  class_methods do
    def sign_in_user
      before do
        user = create(:user, state: :registered)
        sign_in(user)
      end
    end

    def sign_in_superadmin
      before do
        admin = create(:user, :superadmin, project_type: ProjectTypes::ALLOWED_TYPES[:policlinic])
        sign_in(admin)
      end
    end
  end

  define_method(JWTSessions.csrf_header.to_s) { @tokens[:csrf] }
  define_method('X-Key-Inflection') { 'camel' }
  define_method(:current_user) { @current_user }

  def sign_in(user)
    @current_user = user
    payload = { user_id: user.id }
    session = JWTSessions::Session.new(payload: payload, refresh_by_access_allowed: true)
    @tokens = session.login
    cookies[JWTSessions.access_cookie] = @tokens[:access]
  end

  def json_response
    JSON.parse(response.body, symbolize_names: true)
  end
end
