# frozen_string_literal: true

shared_context 'SearchDefaultParams' do |class_name|
  parameter name: :search, in: :query, type: :string
  parameter name: :page, in: :query, type: :integer
  parameter name: :perPage, in: :query, type: :integer, default: Pagy::VARS[:items]
  if class_name.allowed_filters.present?
    parameter name: :'filters[][field]', in: :query, type: :string, description: class_name.allowed_filters.keys.join(', ')
    parameter name: :'filters[][value][]', in: :query, type: :array, items: { type: :integer }, collectionFormat: :multi
  end
  if class_name.allowed_sortings.present?
    parameter name: :'sortings[][field]', in: :query, type: :string, description: class_name.allowed_sortings.keys.join(', ')
    parameter name: :'sortings[][value]', in: :query, type: :string, description: BaseSearcher::ALLOWED_SORTING_VALUES.join(', ')
  end
  let(:'filters[][field]') { '' }
  let(:'filters[][value][]') { [] }
  let(:'sortings[][field]') { 'id' }
  let(:'sortings[][value]') { 'asc' }
  let(:page) { 1 }
  let(:perPage) { 5 }
  let(:search) { '' }
end
