# frozen_string_literal: true

shared_examples_for 'Searchable' do |params = {}|
  class_name = params[:class_name] || described_class.to_s.chomp('Searcher').constantize

  before_all { class_name.reindex }

  context 'without term' do
    subject do
      opts = [{}]
      opts << user if params[:is_user_required]
      opts << current_project_type if params[:project_type_required]

      described_class.call(*opts)
    end

    if params[:is_default_scoped]
      it 'returns default scoped records' do
        expect(subject.results).to include(*default_scoped)
      end
    elsif params[:project_type_required]
      it 'returns filterd by current_project_type' do
        expect(subject.results).to include(*class_name.where(project_type: current_project_type))
      end
    else
      it 'returns all' do
        expect(subject.results).to include(*class_name.all)
      end
    end
  end

  context 'with term' do
    it 'returns only searched' do
      params[:fields].each do |field|
        searcher = begin
          opts = [{ search: searched.send(field) }]
          opts << user if params[:is_user_required]
          opts << current_project_type if params[:project_type_required]

          described_class.call(*opts)
        end

        expected = defined?(expected_result) ? expected_result : searched
        expect(searcher.results.first).to eq expected
      end
    end
  end
end
