# frozen_string_literal: true

shared_examples_for 'Sortable' do |params = {}|
  it "sorts by #{params[:fields]}" do
    params[:fields].each do |field|
      search_params = field == :id ? {} : { sortings: [{ field: field, value: 'asc' }] }

      opts = [search_params]
      opts << user if params[:is_user_required]
      opts << current_project_type if params[:project_type_required]

      searcher = described_class.call(*opts)
      # for cases with nested sortings, such as sort vacations by user's curator's full name. sorting can be written as :'user.curator.full_name'
      expect(field.to_s.split('.').reduce(searcher.results.first) { |found, method_name| found.send(method_name.to_sym) })
        .to be < field.to_s.split('.').reduce(searcher.results.last) { |found, method_name| found.send(method_name.to_sym) }
    end
  end

  it "sorts by #{params[:fields]} DESC" do
    params[:fields].each do |field|
      search_params = { sortings: [{ field: field, value: 'desc' }] }

      opts = [search_params]
      opts << user if params[:is_user_required]
      opts << current_project_type if params[:project_type_required]

      searcher = described_class.call(*opts)

      expect(field.to_s.split('.').reduce(searcher.results.first) { |found, method_name| found.send(method_name.to_sym) })
        .to be > field.to_s.split('.').reduce(searcher.results.last) { |found, method_name| found.send(method_name.to_sym) }
    end
  end
end
