import { Vue, Component, Watch } from 'nuxt-property-decorator'
import { IAuditTime } from '~/ts/interfaces'

@Component
export default class TChecklist extends Vue {
  checklist: any

  get start(): IAuditTime {
    const [date, time] = this.checklist.headerInfo.startsAt.split(' ')
    return time ? { date, time } : { date: '', time: '' }
  }

  get end(): IAuditTime {
    const [date, time] = this.checklist.headerInfo.endsAt.split(' ')
    return time ? { date, time } : { date: '', time: '' }
  }

  get isLoad(): boolean {
    return this.$store.getters['checklist/isLoad']
  }

  get isChecklistExist(): boolean {
    return !!this.$store.getters['checklist/current']
  }

  setAuditTime({ start, end }: { start: IAuditTime, end: IAuditTime }) {
    if (start.time && start.date) {
      this.checklist.headerInfo.startsAt = this.toStrTimeAndDate(start.date, start.time)
    }

    if (end.time && end.date) {
      this.checklist.headerInfo.endsAt = this.toStrTimeAndDate(end.date, end.time)
    }
  }

  toStrTimeAndDate(date: string | Date, time: string): string {
    const newDate = new Date(date)
    return `${newDate.toLocaleDateString()} ${time}`
  }

  created() {
    this.get('location', this.checklist.headerInfo.location)
  }

  create() {
    this.$store.dispatch('checklist/create', { ...this.checklist.headerInfo, blocks: this.checklist.blocks })
  }

  deleteList() {
    this.$store.dispatch('checklist/delete', { key: 'location', value: this.checklist.headerInfo.location })
  }

  get(key: string, value: string) {
    this.$store.dispatch('checklist/get', { key, value })
  }

  update() {
    this.$store.dispatch('checklist/update', {
      key: 'location',
      value: this.checklist.headerInfo.location,
      changes: { ...this.checklist.headerInfo, blocks: this.checklist.blocks }
    })
  }

  save() {
    if (this.isChecklistExist) {
      this.update()
    } else {
      this.create()
    }
  }

  @Watch('isLoad')
  setBlocks(newVal: boolean) {
    if (!newVal && this.$store.getters['checklist/current']) {
      const current = JSON.stringify(this.$store.getters['checklist/current'].blocks)
      this.checklist.blocks = JSON.parse(current)
    }
  }
}
