import { Vue, Component, Prop, Watch } from 'nuxt-property-decorator'

import { mapActions } from 'vuex'
import { FILE_STATES_PROGRESS, FILE_STATES } from '~/assets/utils/constants'
import { readFileAsync } from '~/assets/utils/helpers'
import { IDBFile } from '~/ts/interfaces'

@Component({
  methods: {
    ...mapActions({
      repeatUpload: 'files/repeatFileUpload'
    })
  }
})
export default class FileBaner extends Vue {
  repeatUpload: (fileId: string) => void

  @Prop({ default: '42px' })
  readonly height: string

  @Prop({ default: '42px' })
  readonly width: string

  states = FILE_STATES_PROGRESS
  file: any = null
  isModalOpen: boolean = false

  @Prop()
  readonly fileInfo: IDBFile

  async created() {
    this.file = this.fileInfo.value ? await readFileAsync(this.fileInfo.value) : null
  }

  get isFileLoading(): boolean {
    return [
      FILE_STATES.INITIAL,
      FILE_STATES.UPLOADED_TO_INDEXED_DB,
      FILE_STATES.DIRECT_UPLOAD_COMPLETE,
      FILE_STATES.S3_UPLOAD_COMPLETE
    ].includes(this.fileInfo.state)
  }

  repeatFileUpload() {
    this.repeatUpload(this.fileInfo.id)
  }

  @Watch('fileInfo.value')
  async setNewFileValue() {
    this.file = this.fileInfo.value ? await readFileAsync(this.fileInfo.value) : null
  }
}
