import { Vue, Component, Prop, Watch } from 'nuxt-property-decorator'

import { v4 as uuid } from 'uuid'

import { mapGetters } from 'vuex'
import { IDBFile, IInspection } from '~/ts/interfaces'

@Component({
  computed: {
    ...mapGetters({
      currentInspection: 'inspections/get',
      currentFiles: 'files/get'
    })
  }
})
export default class FileHandler extends Vue {
  currentInspection: IInspection
  currentFiles: any

  @Prop()
  readonly data: string[]

  files: IDBFile[] = []

  created() {
    if (this.data.length) {
      this.onCurrentFilesChange()
    }
  }

  addFiles(event: any) {
    const files = [...event.target.files]
    const DBFiles: IDBFile[] = files.map((el: any) => ({
      id: uuid(),
      S3href: '',
      state: 'initial',
      inspectionId: this.currentInspection.id,
      value: el
    }))

    this.$store.dispatch('files/addNewFiles', DBFiles)

    this.$emit('update', [...this.data, ...DBFiles.map(el => el.id)])
  }

  deleteFile(file: IDBFile) {
    this.$store.dispatch('files/deleteFile', file)

    this.$emit('update', this.data.filter(el => el !== file.id))
  }

  @Watch('data', { deep: true })
  @Watch('currentFiles', { deep: true })
  onCurrentFilesChange() {
    this.files = this.currentFiles.filter((currentFile: any) => this.data.includes(currentFile.id))
  }
}
