const path = require('path')
const { injectManifest, getManifest } = require('workbox-build')
const env = process.env.NODE_ENV || 'development'
export default function nuxtWorkboxExtension() {
  if (env !== 'development' && env !== 'developmentDocker') {
    this.nuxt.hook('build:before', async(nuxt) => {
      let cachingExtensions = nuxt.options.pwa.workbox.cachingExtensions || []
      cachingExtensions = Array.isArray(cachingExtensions) ? cachingExtensions : [cachingExtensions]
      nuxt.options.pwa.workbox.cachingExtensions = [...cachingExtensions, '~/modules/pwa-extension-inject.js']
      const { manifestEntries: assets } = await getManifest({ // find all assets in our project
        globDirectory: this.options.srcDir + '/static',
        globPatterns: [
          '**/*.{svg,jpg,png,jpeg}'
        ]
      })
      const offlineAssets = nuxt.options.pwa.workbox.offlineAssets || []
      nuxt.options.pwa.workbox.offlineAssets = [...offlineAssets, ...assets] // pre cache assets
    })
    this.nuxt.hook('build:compiled', async() => {
      const swFile = path.resolve(this.options.srcDir, this.options.dir.static || 'static', 'sw.js')
      await injectManifest({ // pre cache routes
        globDirectory: this.options.srcDir + '/.nuxt/dist/client',
        globPatterns: [
          '**/*.{js,css}'
        ],
        modifyURLPrefix: {
          '': '/_nuxt/'
        },
        swSrc: swFile,
        swDest: swFile,
        injectionPoint: 'self.__PWA_EXTENSION'
      })
    })
  }
}
