import config from './config'
const resolve = require('path').resolve
// eslint-disable-next-line no-console
console.log('---------------CONFIG---------------')
for (const key in config) {
  // eslint-disable-next-line no-console
  console.log(key + ': ' + config[key])
}

export default {
  /*
  ** Nuxt rendering mode
  ** See https://nuxtjs.org/api/configuration-mode
  */
  mode: 'spa',
  /*
  ** Headers of the page
  ** See https://nuxtjs.org/api/configuration-head
  */
  head: {
    title: 'Мобильный ревизор',
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      { hid: 'description', name: 'description', content: process.env.npm_package_description || '' }
    ],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico?v2' },
      { href: 'https://fonts.googleapis.com/css2?family=Montserrat:wght@400;800&display=swap', rel: 'stylesheet' },
      { rel: 'stylesheet', href: 'https://fonts.googleapis.com/css?family=Material+Icons&display=swap' }
    ],
    script: [
      {
        src: `https://api-maps.yandex.ru/2.1/?apikey=${config.YMAPS}&lang=ru_RU`
      }
    ]
  },
  /*
  ** Global CSS
  */
  css: [
    '~/assets/scss/app.scss'
  ],
  /*
  ** Plugins to load before mounting the App
  ** https://nuxtjs.org/guide/plugins
  */
  plugins: [
    '~/plugins/axios.ts',
    '~/plugins/lodash.ts',
    '~/plugins/load.ts',
    '~/plugins/api.ts',
    '~/plugins/localStorage.ts',
    '~/plugins/deepClone.ts',
    { src: '~/plugins/ymaps.js', ssr: false }
  ],
  /*
  ** Nuxt.js dev-modules
  */
  buildModules: [
    '~/modules/pwa-extension.js',
    '@nuxt/typescript-build',
    '@nuxtjs/stylelint-module',
    '@nuxtjs/vuetify',
    '@nuxtjs/pwa'
  ],
  env: config,
  server: {
    port: config.PORT,
    host: config.HOST
  },
  vuetify: {
    defaultAssets: {
      font: {
        family: 'Roboto'
      }
    },
    customVariables: ['~/assets/scss/variables.scss'],
    theme: {
      themes: {
        light: {
          primary: '#1EC59C'
        }
      }
    }
  },
  /*
  ** Nuxt.js modules
  */
  modules: [
    '@nuxtjs/axios',
    '@nuxtjs/auth'
  ],
  styleResources: {
    scss: [
      resolve(__dirname, './assets/scss/colors.scss')
    ]
  },
  /*
  ** Build configuration
  ** See https://nuxtjs.org/api/configuration-build/
  */
  build: {},
  axios: {
    credentials: true,
    baseURL: config.API_URL
  },
  auth: {
    redirect: {
      login: '/auth/signin',
      logout: '/auth/signin',
      home: '/'
    },
    strategies: {
      local: {
        endpoints: {
          login: {
            url: '/auth/sessions/sign_in',
            method: 'post',
            propertyName: 'csrf'
          },
          logout: {
            url: '/auth/sessions/sign_out',
            method: 'delete'
          },
          user: false
        },
        tokenType: ''
      }
    }
  },
  router: {
    middleware: ['authAdmin']
  },
  pwa: {
    manifest: {
      name: 'Мобильный ревизор',
      short_name: 'Моб. ревизор',
      lang: 'ru'
    },
    workbox: {
      cleanupOutdatedCaches: true,
      runtimeCaching: [ // кэширование запросов
        {
          urlPattern: `${config.API_URL}/.*`,
          strategyOptions: {
            cacheName: 'api-cache'
          }
        },
        {
          urlPattern: 'https://api-maps.yandex.ru/.*',
          strategyOptions: {
            cacheName: 'ymap-cache'
          }
        }
      ],
      cachingExtensions: '@/plugins/workbox-offline-page.js'
    }
  }
}
