export const state = () => ({
  policlinic: {
    kinds: [],
    sizes: []
  },
  criteria: [],
  isLoaded: false
})

export const getters = {
  getPoliclinicKinds: state => state.policlinic.kinds,
  getPoliclinicSizes: state => state.policlinic.sizes,
  getCriteria: state => state.criteria,
  isLoaded: state => state.isLoaded
}

export const mutations = {
  SET_CODEBOOKS(state, { key, value }) {
    state[key] = value
  },
  SET_LOADING_STATE(state, value) {
    state.isLoaded = value
  }
}

export const actions = {
  setCodeBooks({ commit }) {
    const codeBooksQuery = [
      new Promise((resolve, reject) => {
        this.$codebooks.index().then(({ policlinic }) => {
          resolve({ data: policlinic, key: 'policlinic' })
        }).catch(() => {
          reject(new Error('policlinic'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$criteria.index().then(({ criteria }) => {
          resolve({ data: criteria, key: 'criteria' })
        }).catch(() => {
          reject(new Error('criteria'))
        })
      })
    ]
    this.$load(async() => {
      await Promise.allSettled(codeBooksQuery).then((results) => {
        results.forEach((result) => {
          if (result.status === 'fulfilled') {
            commit('SET_CODEBOOKS', { value: result.value.data, key: result.value.key })
          } else {
            commit('SET_CODEBOOKS', { value: [], key: result.reason.message })
          }
        })
        commit('SET_LOADING_STATE', true)
      })
    })
  }
}
