import Vue from 'vue'
import { NuxtAxiosInstance } from '@nuxtjs/axios'

import {
  // inspections
  IInspectionIndexPayload,
  IInspectionUpdatePayload,
  IInspectionIndexResponse,
  IInspectionShowResponse,
  // codebooks
  ICodebooksIndexResponse,
  // criterion
  ICriterionIndexResponse
} from '~/ts/interfaces'

declare module '*.vue' {
  export default Vue
}

declare module 'vue/types/vue' {
  interface Vue {
    $axios: NuxtAxiosInstance
    $ymaps: any
    $load: any
    $auth: any // nuxt-auth module
    $debounce: any

    $inspections: InspectionsAPI
    $codebooks: CodebooksAPI
    $criteria: CriteriaAPI
    $calendarDays: CalendarDaysAPI

    $clone<T>(payload: T): T
  }
}

interface InspectionsAPI extends CustomNuxtAxiosInstance {
  index(payload: IInspectionIndexPayload): Promise<IInspectionIndexResponse>
  show(id: number): Promise<IInspectionShowResponse>
  update(id: number, payload: IInspectionUpdatePayload): Promise<IInspectionShowResponse>
}

interface CodebooksAPI extends CustomNuxtAxiosInstance {
  index(): Promise<ICodebooksIndexResponse>
}

interface CriteriaAPI extends CustomNuxtAxiosInstance {
  index(): Promise<ICriterionIndexResponse>
}

interface CalendarDaysAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBackend): Promise<ICalendarDaysIndexResponse>
}
