import { Vue, Component, Watch } from 'nuxt-property-decorator'
import {
  ICellHeader, IScheduleRow, IScheduleCellContent, IRepairPeriod,
  DayKind, ScheduleActions, IInspectionShowResponse, ScheduleState, IErrorsChannelMessage
} from '@/ts/interfaces'
import { SCHEDULE_ACTIONS, inspectionColors } from '@/assets/utils/constants'

interface IDayForUpdate {
  date: string
  id: number
  isInspectionsExist: boolean
  kind: DayKind
  userId: number
  workingHours: number
}
@Component
export default class VStickyTableMixin extends Vue {
  currentDate = new Date()
  // for dropdown
  disabled = false
  absolute = false
  isShowDropdown = false
  closeOnClick = true
  positionX = 0
  positionY = 0
  currentCol: number = NaN
  currentRow: number = NaN

  headers: ICellHeader[] = []
  content: IScheduleRow[] = []
  daysCount: number = 0
  isLoading: boolean = false
  scheduleState: string = ''

  currentInspection: IInspectionShowResponse | null
  actionsInspectionData: IInspectionShowResponse | null | { inspectorId: number, date: string } = null
  isOpenActionInspectionModal: boolean = false

  scheduleStates = [
    'work_schedule_generating',
    'work_schedule_cleaning',
    'inspection_schedule_generating',
    'inspection_schedule_cleaning'
  ]

  scheduleStatesTexts = {
    work_schedule_generating: 'Рабочий график генерируется',
    work_schedule_cleaning: 'Происходит очистка рабочего графика',
    inspection_schedule_generating: 'График проверок генерируется',
    inspection_schedule_cleaning: 'Происходит очистка графика проверок'
  }

  inspectionsState: any = [
    { text: 'Проверка запланирована', color: 'cyan' },
    { text: 'Проверка начата', color: 'deep-purple' },
    { text: 'Проверка завершена', color: 'primary' }
  ]

  inspectionColors = inspectionColors

  curator: string = ''

  get isPastMonth(): boolean {
    const year = (new Date(this.currentDate)).getFullYear()
    const month = (new Date(this.currentDate)).getMonth()
    return year === (new Date()).getFullYear() ? month < (new Date()).getMonth() : year < (new Date()).getFullYear()
  }

  get isRunningActionWithSchedule(): boolean {
    return this.scheduleStates.includes(this.scheduleState)
  }

  get isDisableActionBtns(): boolean {
    return this.isRunningActionWithSchedule || this.$auth.user.isMFC || this.isPastMonth
  }

  get styleForTableWrapper(): string {
    return `height: calc(100vh - ${this.isRunningActionWithSchedule ? 290 : 222}px);`
  }

  get numberOfWorkingDaysInMonth(): number[] {
    return this.content.map((row: IScheduleRow) => {
      return row.calendarDays.filter((el: IScheduleCellContent) => el.kind === 'working').length
    })
  }

  get countSpecialistsInDays(): number[] {
    if (this.content.length) {
      return this.content[0].calendarDays.map((_col: any, index: number) => {
        return this.content.reduce((res: any, el: any) => {
          return res + Number(el.calendarDays[index].kind === 'working')
        }, 0)
      })
    }
    return []
  }

  get scheduleId() {
    return `${this.currentDate.getFullYear()}-${this.currentDate.getMonth() + 1}`
  }

  get searchableTableKey(): 'inspectorId' | 'inspectableId' {
    return this.$route.path === '/objects-schedule' ? 'inspectableId' : 'inspectorId'
  }

  setContent(daysCount: number, users: any, dataKey: 'calendarDays' | 'inspections' = 'calendarDays') {
    this.content = []
    for (let rowIndex = 0; rowIndex < users.length; rowIndex++) {
      const calendarDays = this.setWorkingDays([...users[rowIndex][dataKey]], users[rowIndex].repairPeriods)

      const row = []
      for (let col = 1; col <= daysCount; col++) {
        row.push({
          id: calendarDays.get(col)?.id || 0,
          isActive: false,
          workingHours: calendarDays.get(col)?.workingHours || '',
          kind: calendarDays.get(col)?.kind || '',
          inspections: calendarDays.get(col)?.inspections || [],
          isInspectionsExist: calendarDays.get(col)?.isInspectionsExist || false
        })
      }

      this.content.push({
        ...users[rowIndex],
        calendarDays: [...row]
      })
    }
    // this.content.splice(0, 100)
  }

  setWorkingDays(_days: any[], _repairPeriods?: IRepairPeriod[]): any {}

  setHeaders(daysCount: number, nonWorkingDays: any, date: Date) {
    this.headers = []
    const daysOfWeek = ['ВС', 'ПН', 'ВТ', 'СР', 'ЧТ', 'ПТ', 'СБ']
    const currDate = date
    const weekend = nonWorkingDays.map((el: any) => new Date(el.date).getDate())

    this.headers = Array(daysCount).fill({ isActive: false }).map((el, i) => {
      currDate.setDate(i + 1)
      const numberOfMonth = i + 1
      return {
        ...el,
        numberOfMonth,
        dayOfWeek: daysOfWeek[currDate.getDay()],
        isOutput: currDate.getDay() === 0,
        isWeekend: weekend.includes(numberOfMonth)
      }
    })
  }

  getDaysInMonth(date: Date) {
    return new Date(date.getFullYear(), date.getMonth() + 1, 0).getDate()
  }

  showDropdown(positionX: number, positionY: number) {
    setTimeout(() => {
      this.isShowDropdown = true
    }, 200)

    this.positionX = positionX
    this.positionY = positionY
  }

  actionWithTable(
    { action, date, inspections, calendarDays, errors, state }:
    {
      action: ScheduleActions,
      date: string,
      inspections: IInspectionShowResponse[],
      calendarDays: IDayForUpdate[],
      errors: any,
      state: ScheduleState
    }
  ) {
    const updateDate = new Date(date)
    const updateId = updateDate ? `${updateDate.getFullYear()}-${updateDate.getMonth() + 1}` : ''
    if (this.scheduleId !== updateId) {
      return
    }
    switch (action) {
      case SCHEDULE_ACTIONS.ERROR:
        this.$store.dispatch('alerts/addAlert', { title: 'Ошибка', text: errors.message.join('. '), type: 'error' })
        break
      case SCHEDULE_ACTIONS.RELOAD:
        this.getSchedule(this.currentDate)
        break
      case SCHEDULE_ACTIONS.STATE_UPDATE:
        this.scheduleState = state
        break
      case SCHEDULE_ACTIONS.INSPECTIONS_DELETE:
        inspections.forEach((inspection: IInspectionShowResponse) => { this.removeInspection(inspection) })
        break
      case SCHEDULE_ACTIONS.INSPECTIONS_CREATE:
        inspections.forEach((inspection: IInspectionShowResponse) => { this.addInspection(inspection) })
        break
      case SCHEDULE_ACTIONS.INSPECTIONS_UPDATE:
        inspections.forEach((inspection: IInspectionShowResponse) => {
          this.updateInspection(inspection)
        })
        break
      case SCHEDULE_ACTIONS.CALENDAR_DAYS_UPDATE:
        calendarDays.forEach((day: IDayForUpdate) => { this.updateCalendarDay(day) })
        break
    }
  }

  updateInspection(inspection: IInspectionShowResponse) {
    this.removeInspection(inspection)
    this.addInspection(inspection)
  }

  removeInspection(inspection: IInspectionShowResponse) {
    const { row, col, inspections } = this.getInspectionsFromCell(inspection)
    this.content[row].calendarDays[col].inspections = inspections?.filter(el => el.id !== inspection.id)
  }

  addInspection(inspection: IInspectionShowResponse) {
    const { row, col } = this.getInspectionsFromCell(inspection)
    this.content[row].calendarDays[col].inspections?.push(inspection)
  }

  updateCalendarDay(day: IDayForUpdate) {
    const { row, col } = this.getCellByDay(day)
    const cell = this.content[row].calendarDays[col]
    this.$set(this.content[row].calendarDays, col, { ...cell, ...day })
  }

  getCellByDay({ userId, date }: {userId: number, date: string }) {
    const row = this.content.findIndex((el: IScheduleRow) => el.id === userId)
    const col = new Date(date).getDate() - 1
    return { row, col }
  }

  getInspectionsFromCell(inspection: IInspectionShowResponse) {
    const row = this.content.findIndex((el: IScheduleRow) => el.id === inspection[this.searchableTableKey])
    const col = new Date(inspection.date).getDate() - 1
    const inspections = this.content[row].calendarDays[col].inspections
    return { row, col, inspections }
  }

  getSchedule(_date: Date) {}

  deselectAll() {
    for (let row = 0; row < this.content.length; row++) {
      for (let col = 0; col < this.content[row].calendarDays.length; col++) {
        this.content[row].calendarDays[col].isActive = false
      }
    }
  }

  errorHandler({ errors }: IErrorsChannelMessage) {
    this.$store.dispatch('alerts/addAlert', { title: 'Ошибка', text: errors.message.join('. '), type: 'error' })
  }

  clearValue() {
    this.actionsInspectionData = null
    this.currentInspection = null
  }

  @Watch('$auth.user.projectType')
  changeProjectOnMfc() {
    this.getSchedule(this.currentDate)
  }
}
