import { Vue, Component } from 'nuxt-property-decorator'
import { mapGetters } from 'vuex'

import { IChecklist, ICodeBookItem, IChecklistCreateResponse, IChecklistConstructor } from '~/ts/interfaces'

@Component({
  computed: {
    ...mapGetters({
      codeBookChecklists: 'codeBooks/getChecklists'
    })
  }
})
export default class VSubmitChecklistActionMixin extends Vue {
  codeBookChecklists: ICodeBookItem[]
  routerNameTo: string = 'checklists'
  isShowCancelModal: boolean = false
  $refs: {
    VActionWithChecklist: any
  }

  get isChecklistConstructorWasChanged(): boolean {
    const checklistInitialState = this.$store.getters['constructorChecklist/getChecklistInitialState']
    const currentChecklistState = this.$store.getters['constructorChecklist/getConstructorChecklist']
    return this.$isEqual(checklistInitialState, currentChecklistState)
  }

  beforeRouteLeave(to: any, _from: any, next: any) {
    if (to.params.isRedirect !== 'true' && !this.isChecklistConstructorWasChanged) {
      if (this.$refs.VActionWithChecklist) {
        this.$refs.VActionWithChecklist.setConstructorStore()
      }
      this.isShowCancelModal = true
      this.routerNameTo = to.name
      next(false)
    } else {
      if (this.isLeaveChecklistsPage(to.name)) {
        this.$store.dispatch('constructorChecklist/clearData')
      }
      next()
    }
  }

  saveChecklist(isRedirected: boolean = true) {
    const checklist: IChecklist = this.$store.getters['constructorChecklist/getChecklist']
    this.$load(async() => {
      let isRedirectedLocal: boolean = isRedirected
      let newChecklist: IChecklistCreateResponse
      let isFromCreatePage: boolean = false
      if (checklist.id) {
        newChecklist = await this.$checklists.update(checklist.id, {
          projectType: checklist.projectType,
          rawData: JSON.stringify(checklist),
          name: checklist.name
        })
        this.$store.dispatch('updateIndexPageItem', newChecklist)
        this.$store.dispatch('codeBooks/setChecklists', this.codeBookChecklists.map((el) => {
          return el.id === newChecklist.id ? newChecklist : el
        }))
      } else {
        newChecklist = await this.$checklists.create({
          projectType: checklist.projectType,
          rawData: JSON.stringify(checklist),
          name: checklist.name
        })
        this.$store.dispatch('addIndexPageItem', newChecklist)
        this.$store.dispatch('codeBooks/setChecklists', [...this.codeBookChecklists, newChecklist])
        if (!isRedirectedLocal) {
          isFromCreatePage = true
          isRedirectedLocal = true
          if (this.$route.fullPath.includes('preview')) {
            this.routerNameTo = 'checklists-id-edit-preview'
          } else {
            this.routerNameTo = 'checklists-id-edit'
          }
        }
      }
      this.saveChecklistInitialState(this.$store.getters['constructorChecklist/getConstructorChecklist'])
      if (isRedirectedLocal) {
        if (this.isLeaveChecklistsPage(this.routerNameTo)) {
          this.$store.dispatch('constructorChecklist/clearData')
        }
        const params: {[key: string]: string} = isFromCreatePage ? { id: `${newChecklist.id}`, isRedirect: 'true' } : { isRedirect: 'true' }
        this.$router.push({ name: this.routerNameTo, params })
      }
    })
  }

  cancelEditChecklist() {
    this.$store.dispatch('constructorChecklist/clearData')
    this.$router.push({ name: this.routerNameTo, params: { isRedirect: 'true' } })
  }

  saveChecklistInitialState(checklist: IChecklistConstructor) {
    this.$store.dispatch('constructorChecklist/setChecklistInitialState', checklist)
  }

  isLeaveChecklistsPage(routeName: string): boolean {
    return !routeName.includes('checklists-id-edit-preview') &&
      !routeName.includes('checklists-id-edit') &&
      !routeName.includes('checklists-create') &&
      !routeName.includes('checklists-create-preview')
  }
}
