import {
  ICommonIndexPayload,
  ICommonIndexPayloadURL,
  ISortItem
} from '~/ts/interfaces'

const fullName = ({ firstName, lastName, middleName }: { firstName: string, lastName: string, middleName: string }) => {
  return `${lastName} ${firstName} ${middleName || ''}`
}

const shortFullName = ({ firstName, lastName, middleName }: { firstName: string, lastName: string, middleName: string }): string => {
  return `${lastName} ${firstName[0]}.${middleName ? `${middleName[0]}.` : ''}`
}

const formatNumber = (num: number): string => {
  return num < 10 ? `0${num}` : `${num}`
}

const fullDate = (date: string | Date | number) => {
  const newDate = new Date(date)
  return date ? `${formatNumber(newDate.getDate())}.${formatNumber(newDate.getMonth() + 1)}.${newDate.getFullYear()}` : ''
}

const getTime = (date: string | number) => {
  const newDate = new Date(date)
  return date ? `${formatNumber(newDate.getHours())}:${formatNumber(newDate.getMinutes())}` : ''
}

const formatMinetsToTime = (formatMinutes: number) => {
  const hours = formatNumber(Math.floor(formatMinutes / 60))
  const minutes = formatNumber(Math.floor(formatMinutes % 60))
  return `${hours}:${minutes}`
}

const fullDateAndTime = (date: string) => {
  return date ? `${fullDate(date)} ${getTime(date)}` : ''
}

const toVuetifyDate = (date: string) => {
  return date.split('.').reverse().join('-')
}

const toDateFromVuetifyDate = (date: string) => {
  return date.split('-').reverse().join('.')
}

const getDaysInMonthFromVuetifyDate = (date: string): number => {
  const year = Number(date.split('-')[0])
  const month = Number(date.split('-')[1])
  return new Date(year, month, 0).getDate()
}
const toCamelCase = (str: string) => {
  return str.replace(/[-_](.)/g, (_, c) => c.toUpperCase())
}

const getUniqId = (): number => {
  return Date.now() + Math.random()
}

const payloadForURL = (payload: ICommonIndexPayload) => {
  const localPayload = JSON.parse(JSON.stringify(payload))
  const newPayload: ICommonIndexPayloadURL = {}
  for (const key in localPayload.filters) {
    if (localPayload.filters[key].value && localPayload.filters[key].value.length && localPayload.filters[key].value[0]) {
      newPayload[localPayload.filters[key].field] = localPayload.filters[key].value[0]
    } else if (localPayload.filters[key].range && (localPayload.filters[key].range.gte || localPayload.filters[key].range.lte)) {
      newPayload[`${localPayload.filters[key].field}-start`] = localPayload.filters[key].range.gte
      newPayload[`${localPayload.filters[key].field}-end`] = localPayload.filters[key].range.lte
    }
  }
  localPayload.sortings?.forEach((el: ISortItem) => {
    if (el.value) {
      newPayload.sortBy = el.field
      newPayload.sortDesc = String(el.value === 'desc')
    }
  })
  newPayload.perPage = localPayload.perPage || 10
  newPayload.page = localPayload.page || 1
  newPayload.search = localPayload.search || ''
  return newPayload
}

export * from '~/assets/utils/helpers/files'
export * from '~/assets/utils/helpers/directUpload'
export * from '~/assets/utils/helpers/inspections'

export {
  fullName,
  shortFullName,
  fullDate,
  getTime,
  fullDateAndTime,
  toVuetifyDate,
  getDaysInMonthFromVuetifyDate,
  toDateFromVuetifyDate,
  formatNumber,
  toCamelCase,
  getUniqId,
  payloadForURL,
  formatMinetsToTime
}
