import config from './config'
// eslint-disable-next-line no-console
console.log('---------------CONFIG---------------')
for (const key in config) {
  // eslint-disable-next-line no-console
  console.log(key + ': ' + config[key])
}

export default {
  /*
  ** Nuxt rendering mode
  ** See https://nuxtjs.org/api/configuration-mode
  */
  mode: 'spa',
  /*
  ** Nuxt target
  ** See https://nuxtjs.org/api/configuration-target
  */
  target: 'server',
  /*
  ** Headers of the page
  ** See https://nuxtjs.org/api/configuration-head
  */
  head: {
    title: 'Мобильный ревизор',
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      { hid: 'description', name: 'description', content: process.env.npm_package_description || '' }
    ],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico?v2' },
      { rel: 'stylesheet', href: 'https://fonts.googleapis.com/css?family=Material+Icons&display=swap' }
    ],
    script: [
      {
        src: `https://api-maps.yandex.ru/2.1/?apikey=${config.YMAPS}&lang=ru_RU`
      }
    ]
  },
  /*
  ** Global CSS
  */
  css: [
    '~/assets/styles/app.scss'
  ],
  /*
  ** Plugins to load before mounting the App
  ** https://nuxtjs.org/guide/plugins
  */
  plugins: [
    '~/plugins/axios.ts',
    '~/plugins/api.ts',
    '~/plugins/lodash.ts',
    '~/plugins/localStorage.ts',
    '~/plugins/load.ts',
    '~/plugins/actioncable.ts',
    '~/plugins/draggable.ts',
    '~/plugins/deepClone.ts',
    { src: '~/plugins/ymaps.js', ssr: false }
  ],
  /*
  ** Auto import components
  ** See https://nuxtjs.org/api/configuration-components
  */
  components: true,
  /*
  ** Nuxt.js dev-modules
  */
  buildModules: [
    '@nuxt/typescript-build',
    // Doc: https://github.com/nuxt-community/stylelint-module
    '@nuxtjs/stylelint-module',
    '@nuxtjs/vuetify'
  ],
  /*
  ** Nuxt.js modules
  */
  modules: [
    '@nuxtjs/axios',
    '@nuxtjs/auth'
  ],
  /*
  ** vuetify module configuration
  ** https://github.com/nuxt-community/vuetify-module
  */
  env: config,
  server: {
    port: config.PORT,
    host: config.HOST
  },
  vuetify: {
    defaultAssets: {
      font: {
        family: 'Roboto'
      }
    },
    customVariables: ['~/assets/variables.scss'],
    theme: {
      themes: {
        light: {
          primary: '#26a69a'
        }
      }
    }
  },
  axios: {
    credentials: true,
    baseURL: config.API_URL
  },
  auth: {
    redirect: {
      login: '/auth/signin',
      logout: '/auth/signin',
      // next-release change to /
      home: '/inspections'
    },
    strategies: {
      local: {
        endpoints: {
          login: {
            url: '/auth/sessions/sign_in',
            method: 'post',
            propertyName: 'csrf'
          },
          logout: {
            url: '/auth/sessions/sign_out',
            method: 'delete'
          },
          user: false
        },
        tokenType: ''
      }
    }
  },
  router: {
    middleware: ['authAdmin']
  },
  /*
  ** Build configuration
  ** See https://nuxtjs.org/api/configuration-build/
  */
  build: {
  }
}
