export const state = () => ({
  data: {
    projectType: [],
    roles: [],
    policlinicKinds: [],
    policlinicSizes: [],
    mfcDivisions: [],
    mfcKinds: [],
    territories: [],
    curators: [],
    administrativeDistricts: [],
    inspectionStates: [],
    checklists: [],
    policlinics: [],
    mfcs: [],
    users: [],
    criteria: [],
    reportKinds: [],
    userStates: [],
    inspectionCancelReasons: [],
    calendarDayHookyReasons: []
  }
})

export const getters = {
  getProjectType: state => state.data.projectType,
  getRoles: state => state.data.roles,
  getPoliclinicKinds: state => state.data.policlinicKinds,
  getPoliclinicSizes: state => state.data.policlinicSizes,
  getMfcDivisions: state => state.data.mfcDivisions,
  getMfcKinds: state => state.data.mfcKinds,
  getTerritories: state => state.data.territories,
  getCurators: state => state.data.curators,
  getAdministrativeDistricts: state => state.data.administrativeDistricts,
  getInspectionStates: state => state.data.inspectionStates,
  getChecklists: state => state.data.checklists,
  getPoliclinics: state => state.data.policlinics,
  getMfcs: state => state.data.mfcs,
  getUsers: state => state.data.users,
  getCriteria: state => state.data.criteria,
  getReportKinds: state => state.data.reportKinds,
  getUserStates: state => state.data.userStates,
  getInspectionCancelReasons: state => state.data.inspectionCancelReasons,
  getCalendarDayHookyReasons: state => state.data.calendarDayHookyReasons
}

export const mutations = {
  SET_STATE(state, value) {
    state.data[value.key] = value.values
  }
}

export const actions = {
  updateUsers({ commit }) {
    this.$load(async() => {
      const payload = {
        page: 1,
        perPage: 1000,
        search: '',
        filters: [],
        sortings: [{ field: 'full_name' }, { value: 'asc' }]
      }

      payload.filters.push({
        field: 'project_type',
        value: [this.$auth.user.projectType]
      })

      const { users } = await this.$users.index(payload)
      commit('SET_STATE', { values: users, key: 'users' })
    })
  },

  updateCurators({ commit }) {
    this.$load(async() => {
      const result = await this.$axios.$get('/admin/codebooks/curators')
      commit('SET_STATE', { values: result, key: 'curators' })
    })
  },

  updateChecklists({ commit }) {
    this.$load(async() => {
      const result = await this.$axios.$get('/admin/codebooks/checklists')
      commit('SET_STATE', { values: result, key: 'checklists' })
    })
  },

  setChecklists({ commit }, newChecklists) {
    commit('SET_STATE', { values: newChecklists, key: 'checklists' })
  },

  setPoliclinics({ commit }, newPoliclinics) {
    commit('SET_STATE', { values: newPoliclinics, key: 'policlinics' })
  },

  setMfcs({ commit }, newMfcs) {
    commit('SET_STATE', { values: newMfcs, key: 'mfcs' })
  },

  setUsers({ commit }, newUsers) {
    commit('SET_STATE', { values: newUsers, key: 'users' })
  },

  setCurators({ commit }, newCurators) {
    commit('SET_STATE', { values: newCurators, key: 'curators' })
  },

  setCriteria({ commit }, newCriteria) {
    commit('SET_STATE', { values: newCriteria, key: 'criteria' })
  },

  updateCriteria({ commit }) {
    this.$load(async() => {
      const { criteria } = await this.$criteria.index({
        perPage: 1000,
        sortings: [
          {
            field: 'position',
            value: 'asc'
          }
        ]
      })
      commit('SET_STATE', { values: criteria, key: 'criteria' })
    })
  },

  setCodeBook({ commit }) {
    const codeBooksQuery = [
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/project_types').then((r) => {
          resolve({ data: r, key: 'projectType' })
        }).catch(() => {
          reject(new Error('projectType'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/roles').then((r) => {
          resolve({ data: r, key: 'roles' })
        }).catch(() => {
          reject(new Error('roles'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/policlinic_kinds').then((r) => {
          resolve({ data: r, key: 'policlinicKinds' })
        }).catch(() => {
          reject(new Error('policlinicKinds'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/policlinic_sizes').then((r) => {
          resolve({ data: r, key: 'policlinicSizes' })
        }).catch(() => {
          reject(new Error('policlinicSizes'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/mfc_divisions').then((r) => {
          resolve({ data: r, key: 'mfcDivisions' })
        }).catch(() => {
          reject(new Error('mfcDivisions'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/mfc_kinds').then((r) => {
          resolve({ data: r, key: 'mfcKinds' })
        }).catch(() => {
          reject(new Error('mfcKinds'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/territories').then((r) => {
          resolve({ data: r, key: 'territories' })
        }).catch(() => {
          reject(new Error('territories'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/curators').then((r) => {
          resolve({ data: r, key: 'curators' })
        }).catch(() => {
          reject(new Error('curators'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/administrative_districts').then((r) => {
          resolve({ data: r, key: 'administrativeDistricts' })
        }).catch(() => {
          reject(new Error('administrativeDistricts'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/inspection_states').then((r) => {
          resolve({ data: r, key: 'inspectionStates' })
        }).catch(() => {
          reject(new Error('inspectionStates'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/checklists').then((r) => {
          resolve({ data: r, key: 'checklists' })
        }).catch(() => {
          reject(new Error('checklists'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/policlinics').then((r) => {
          resolve({ data: r, key: 'policlinics' })
        }).catch(() => {
          reject(new Error('policlinics'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/mfcs').then((r) => {
          resolve({ data: r, key: 'mfcs' })
        }).catch(() => {
          reject(new Error('mfcs'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/report_kinds').then((r) => {
          resolve({ data: r, key: 'reportKinds' })
        }).catch(() => {
          reject(new Error('reportKinds'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/states').then((r) => {
          resolve({ data: r, key: 'userStates' })
        }).catch(() => {
          reject(new Error('userStates'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/inspection_cancel_reasons').then((r) => {
          resolve({ data: r, key: 'inspectionCancelReasons' })
        }).catch(() => {
          reject(new Error('inspectionCancelReasons'))
        })
      }),
      new Promise((resolve, reject) => {
        this.$axios.$get('/admin/codebooks/calendar_day_absence_reasons').then((r) => {
          resolve({ data: r, key: 'calendarDayHookyReasons' })
        }).catch(() => {
          reject(new Error('calendarDayHookyReasons'))
        })
      })
    ]

    codeBooksQuery.push(new Promise((resolve, reject) => {
      this.$criteria.index({
        perPage: 1000,
        sortings: [
          {
            field: 'position',
            value: 'asc'
          }
        ]
      }).then((r) => {
        resolve({ data: r.criteria, key: 'criteria' })
      }).catch(() => {
        reject(new Error('criteria'))
      })
    }))

    this.$load(async() => {
      await Promise.allSettled(codeBooksQuery).then((results) => {
        results.forEach((result) => {
          if (result.status === 'fulfilled') {
            commit('SET_STATE', { values: result.value.data, key: result.value.key })
          } else {
            commit('SET_STATE', { values: [], key: result.reason.message })
          }
        })
      })
    })
  }
}
