export type IUserRole = 'inspector' | 'curator' | 'admin' | 'superadmin'
export type IProjectType = 'policlinic' | 'mfc' | 'no_project'
export type IGender = 'male' | 'female'
export type IPoliclinicKind = 'adult' | 'children' | 'adult_and_children'
export type IPoliclinicSize = 's' | 'm' | 'l' | 'xl'
export type IMfcDivision = 'first' | 'second' | 'third'
export type IMfcKind = 'flagman' | 'regular'
export type ScheduleActions = 'error' | 'reload' |'state_update' | 'inspections_delete' | 'inspections_create' | 'inspections_update' | 'calendar_days_update'
export type ITypeFields = 'input' | 'select' | 'checkbox'
export type ISortDirection = 'asc' | 'desc' | ''
export type ScheduleState = 'initial' | 'work_schedule_generating' | 'work_schedule_generated' | 'work_schedule_cleaning' | 'inspection_schedule_generating' | 'inspection_schedule_generated' | 'inspection_schedule_cleaning'
export type IInspectionsState = '' | 'planned' | 'started' | 'finished' | 'canceled'
export type UserState = 'archived' | 'invited' | 'registered'
export type IInspectorsState = 'notWorking' | 'notWorkingByReason' | 'working' | 'withoutInspections'
export type IInspectorsDatasetType = IInspectorsState | 'total'

export interface ICommonCreateResponse {
  code: number,
  data: {
    id: number
  }
}

export interface ICommonUpdateResponse {
  data: {
    id: number
  }
}

export interface ICommonIndexPayload {
  search?: string
  page: number
  perPage: number
  filters?: IFilterItem
  sortings?: ISortItem[]
}

export interface ICommonIndexPayloadForBeckEnd {
  search?: string
  page: number
  perPage: number
  filters?: IFilterItemForBeckEnd[]
  sortings?: ISortItem[]
}

export interface IFilterItemForBeckEnd {
  field: string
  value?: string[] | number[]
  range?: IRangeFilter
}

export interface ICommonIndexPayloadURL {
  [key: string] : string
}

export interface IIteratorsItem {
  text: string
  value: string
}

export interface IFilterItem {
  [key: string] : {
    field: string
    value?: string[] | number[]
    range?: IRangeFilter
  }
}

export interface IRangeFilter {
  gte: string
  lte: string
}

export interface IAlert {
  text: string
  type: 'success' | 'error'
  timeout: number
}

export interface ISortItem {
  field: string,
  value: ISortDirection
}

export interface ITableHeader {
  text: string
  value: string
  align?: 'left' | 'center' | 'right'
  sortable?: boolean
  class?: string | string[]
  width?: string | number
}

export interface ICodeBookItem {
  id: string | number,
  name: string
}

export interface IMuneGroups {
  icon: string
  title: string
  roles?: string[]
  projectTypes?: string[]
  to?: string
  children?: IMuneGroupsItem[]
}

export interface IMuneGroupsItem {
  title: string
  roles: string[]
  projectTypes: string[]
  to: string,
  classes?: string
  disabled?: boolean
}

export * from '~/ts/interfaces/users'
export * from '~/ts/interfaces/policlinics'
export * from '~/ts/interfaces/mfcs'
export * from '~/ts/interfaces/workSchedules'
export * from '~/ts/interfaces/inspectionSchedules'
export * from '~/ts/interfaces/inspections'
export * from '~/ts/interfaces/hours-norm'
export * from '~/ts/interfaces/checklists/constructor'
export * from '~/ts/interfaces/checklists/list'
export * from '~/ts/interfaces/checklists'
export * from '~/ts/interfaces/criterion'
export * from '~/ts/interfaces/repair-period'
export * from '~/ts/interfaces/vacations'
export * from '~/ts/interfaces/reports'
export * from '~/ts/interfaces/db'
export * from '~/ts/interfaces/errorsChannel'
export * from '~/ts/interfaces/ObjectSchedules'
export * from '~/ts/interfaces/charts'
export * from '~/ts/interfaces/map'
export * from '~/ts/interfaces/fileArchives'
