import {
  IRangeFilter,
  ICommonCreateResponse,
  ICommonUpdateResponse,
  ICommonIndexPayload,
  IInspectionsState
} from '~/ts/interfaces'

export interface IInspectionIndexPayload extends ICommonIndexPayload{
  filters: {
    inspectorId: {
      field: 'inspector_id',
      value: []
    },
    inspectableId: {
      field: 'inspectable_id',
      value: []
    },
    checklistId: {
      field: 'checklist_id',
      value: []
    },
    date: {
      field: 'date',
      range: IRangeFilter
    },
    state: {
      field: 'state',
      value: []
    },
    cancelReason: {
      field: 'cancel_reason',
      value: []
    },

  }
}

export interface IInspectionIndexResponse {
  currentPage: number
  pageItems: number
  totalPages: number
  totalCount: number
  inspections: IInspectionIndex[]
}

export interface IInspectionIndex {
  id: number
  date: string
  startsAt: string
  endsAt: string | null
  inspectorShortFullName: string
  inspectorId: number
  inspectableName: string
  inspectableId: number
  checklistName: string
  checklistId: number
  projectType: string
  state: 'canceled' | 'started' | 'planned' | 'finished'
  cancelReason: string
  updatedAt: string
}

export interface IInspectionCreatePayload {
  inspectableId: number
  inspectableType: string
  checklistId: number
  date: string
  startsAt: string
  inspectorId: number
}

export interface IInspectionCreateResponse extends ICommonCreateResponse {}

export interface IInspectionUpdatePayload {
  inspectableId?: number
  inspectableType?: string
  checklistId?: number
  date?: string
  startsAt?: string
  inspectorId?: number
  rawDate?: string
  state?: IInspectionsState
}

export interface IInspectionUpdateResponse extends ICommonUpdateResponse {}

export interface IInspectionShowResponse {
  id: number
  date: string
  rawData: string
  startsAt: string
  endsAt: string
  state: IInspectionsState
  inspectorShortFullName: string
  inspectorId: number
  inspectableName: string
  inspectableId: number
  checklistName: string
  checklistId: number
  projectType: string
  timeToInspectMinutes: number
}

export interface IInspectionDeleteResponse {
  id: number
  state: IInspectionsState
  cancelReason: string
  error?: string
}

export interface IInspectionCansleResponse extends IInspectionIndex {
  errors?: string
}

export interface IInspectorWithInspections {
  id: number
  fullName: string
  latitude: number
  longitude: number
  inspections: IInspectorsInspection[]
}

export interface IInspectorsInspection {
  id: number
  startsAt: string
  timeToInspectMinutes: number
  inspectableName: string
  inspectableAddress: string
  state: IInspectionsState
  inspectableLatitude: number
  inspectableLongitude: number
}
