import Vue from 'vue'
import { NuxtAxiosInstance } from '@nuxtjs/axios'
import {
  // User
  IUserCreate,
  IUserUpdate,
  IUserShow,
  IUserIndexResponse,
  // Policlinic
  IPoliclinicCreate,
  IPoliclinicUpdate,
  IPoliclinicShow,
  // mfc
  IMfcIndexResponse,
  IMfcShowResponse,
  IMfcCreatePayload,
  IMfcUpdatePayload,
  IMfcDeleteResponse,
  // Inspection
  IInspectionIndexResponse,
  IInspectionShowResponse,
  IInspectionCreatePayload,
  IInspectionCreateResponse,
  IInspectionUpdatePayload,
  IInspectionUpdateResponse,
  IInspectionDeleteResponse,
  // Checklist
  IChecklistIndexResponse,
  IChecklistShowResponse,
  IChecklistCreatePayload,
  IChecklistCreateResponse,
  IChecklistUpdatePayload,
  IChecklistUpdateResponse,
  IChecklistDeleteResponse,
  // HourNorm
  IHourIndexResponse,
  IHourCreateResponse,
  IHourUpdateResponse,
  IHourUpdate,
  IHourShow,
  IHourCreate,
  // Criterion
  ICriterionIndexResponse,
  ICriterionShow,
  ICriterionCreate,
  ICriterionUpdate,
  // Rapair-period
  IRepairPeriodCreate,
  IRepairPeriodCreateResponse,
  IRepairPeriodUpdate,
  IRepairPeriodUpdateResponse,
  // Vacations
  // ObjectSchedules
  IObjectSchedulesShowResponse,
  // Reports
  IReportCreate,
  // FileArchive
  IFileArchivesIndexResponse,
  IFileArchivesShowResponse
} from '~/ts/interfaces'

declare module '*.vue' {
  export default Vue
}

declare module 'vue/types/options' {
  interface ComponentOptions<V extends Vue> {
    channels?: any
  }
}

declare module 'vue/types/vue' {
  interface Vue {
    $axios: NuxtAxiosInstance
    $auth: any // nuxt-auth module
    $cable: any // actiocable plugin
    $clone<T>(payload: T): T

    $debounce: any
    $isEqual: any
    $load: any
    $moment: any

    $ymaps: any

    // api
    $users: UsersAPI
    $policlinics: PoliclinicsAPI
    $mfcs: MfcsAPI
    $holidays: any
    $vacations: VacationsAPI
    $criteria: CriteriaAPI
    $workSchedules: WorkSchedulesAPI
    $inspectionSchedules: InspectionSchedulesAPI
    $objectSchedules: ObjectSchedulesAPI
    $inspections: InspectionsAPI
    $checklists: ChecklistsAPI
    $workingNorms: HourNormAPI
    $repairPeriods: RepairPeriodAPI
    $reports: ReportsAPI
    $fileArchives: FileArchivesAPI
  }
}

interface UsersAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IUserIndexResponse>
  show(id: number | string): Promise<IUserShow>
  create(payload: IUserCreate): Promise<IUserShow>
  update(id: number | string, payload: IUserUpdate): Promise<IUserShow>
  delete(id: number | string): Promise<IUserDeleteResponse>
}

interface PoliclinicsAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IAUserIndexResponse>
  show(id: number | string): Promise<IPoliclinicShow>
  create(payload: IPoliclinicCreate): Promise<IPoliclinicShow>
  update(id: number | string, payload: IPoliclinicUpdate): Promise<IPoliclinicShow>
  delete(id: number | string): Promise<?IAUserDeleteResponse>
}

interface MfcsAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IMfcIndexResponse>
  show(id: number): Promise<IMfcShowResponse>
  create(payload: IMfcCreatePayload): Promise<IMfcShowResponse>
  update(id: number, payload: IMfcUpdatePayload): Promise<IMfcShowResponse>
  delete(id: number): Promise<IMfcDeleteResponse>
}

interface InspectionsAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IInspectionIndexResponse>
  show(id: number): Promise<IInspectionShowResponse>
  create(payload: IInspectionCreatePayload): Promise<IInspectionCreateResponse>
  update(id: number, payload: IInspectionUpdatePayload): Promise<IInspectionUpdateResponse>
  delete(id: number, payload?: { 'cancel_reason'?: string }): Promise<IInspectionDeleteResponse>
}

interface HourNormAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IHourIndexResponse>
  show(id: number): Promise<IHourShow>
  create(payload: IHourCreate): Promise<IHourCreateResponse>
  update(id: number, payload: IHourUpdate): Promise<IHourUpdateResponse>
  delete(id: number): Promise<IHourDeleteResponse>
}

interface WorkSchedulesAPI extends CustomNuxtAxiosInstance {
  show(id: string): Promise<IWorkSchedulesShowResponse>
  create({ month }: { month: string }): Promise<IWorkSchedulesCreateResponse>
  update(id: string, { calendarDays }: { calendarDays: any[] }): Promise<any>
  delete(id: string): Promise<IInspectionSchedulesDeleteResponse>
}

interface InspectionSchedulesAPI extends CustomNuxtAxiosInstance {
  create({ month, checklistId }: { month: string, checklistId: number }): Promise<IInspectionSchedulesCreateResponse>
  show(id: string): Promise<IInspectionSchedulesShowResponse>
  delete(id: string): Promise<IInspectionSchedulesDeleteResponse>
}

interface ChecklistsAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IChecklistIndexResponse>
  show(id: number): Promise<IChecklistShowResponse>
  create(payload: IChecklistCreatePayload): Promise<IChecklistCreateResponse>
  update(id: number, payload: IChecklistUpdatePayload): Promise<IChecklistUpdateResponse>
  delete(id: number): Promise<IChecklistDeleteResponse>
}

interface CriteriaAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<ICriterionIndexResponse>
  show(id: number): Promise<ICriterionShow>
  create(payload: ICriterionCreate): Promise<ICriterionShow>
  update(id: number, payload: ICriterionUpdate): Promise<ICriterionShow>
  delete(id: number): Promise<ICriterionDeleteResponse>
}

interface RepairPeriodAPI extends CustomNuxtAxiosInstance {
  create(payload: IRepairPeriodCreate): Promise<IRepairPeriodCreateResponse>
  update(id: number, payload: IRepairPeriodUpdate): Promise<IRepairPeriodUpdateResponse>
  delete(id: number): Promise<IRepairPeriodDeleteResponse>
}

interface VacationsAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayloadForBeckEnd): Promise<IVacationIndexResponse>
  show(id: number): Promise<IVacationShow>
  create(payload: IVacationCreate): Promise<IVacationCreateResponse>
  update(id: number, payload: IVacationUpdate): Promise<IVacationUpdateResponse>
  delete(id: number): Promise<IVacationDeleteResponse>
}

interface ReportsAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayload): Promise<IReportsIndexResponse>
  create(payload: IReportCreate): Promise<IReportsCreateResponse>
}

interface ObjectSchedulesAPI extends CustomNuxtAxiosInstance {
  show(id: string): Promise<IObjectSchedulesShowResponse>
}

interface FileArchivesAPI extends CustomNuxtAxiosInstance {
  index(payload: ICommonIndexPayload): Promise<IFileArchivesIndexResponse>
  show(id: string): Promise<IFileArchivesShowResponse>
}
